geo_names={
 (0, 0): u'US',
 (1, 0): u'Alabama',
 (1, 1): u'Autauga County, Alabama',
 (1, 3): u'Baldwin County, Alabama',
 (1, 5): u'Barbour County, Alabama',
 (1, 7): u'Bibb County, Alabama',
 (1, 9): u'Blount County, Alabama',
 (1, 11): u'Bullock County, Alabama',
 (1, 13): u'Butler County, Alabama',
 (1, 15): u'Calhoun County, Alabama',
 (1, 17): u'Chambers County, Alabama',
 (1, 19): u'Cherokee County, Alabama',
 (1, 21): u'Chilton County, Alabama',
 (1, 23): u'Choctaw County, Alabama',
 (1, 25): u'Clarke County, Alabama',
 (1, 27): u'Clay County, Alabama',
 (1, 29): u'Cleburne County, Alabama',
 (1, 31): u'Coffee County, Alabama',
 (1, 33): u'Colbert County, Alabama',
 (1, 35): u'Conecuh County, Alabama',
 (1, 37): u'Coosa County, Alabama',
 (1, 39): u'Covington County, Alabama',
 (1, 41): u'Crenshaw County, Alabama',
 (1, 43): u'Cullman County, Alabama',
 (1, 45): u'Dale County, Alabama',
 (1, 47): u'Dallas County, Alabama',
 (1, 49): u'DeKalb County, Alabama',
 (1, 51): u'Elmore County, Alabama',
 (1, 53): u'Escambia County, Alabama',
 (1, 55): u'Etowah County, Alabama',
 (1, 57): u'Fayette County, Alabama',
 (1, 59): u'Franklin County, Alabama',
 (1, 61): u'Geneva County, Alabama',
 (1, 63): u'Greene County, Alabama',
 (1, 65): u'Hale County, Alabama',
 (1, 67): u'Henry County, Alabama',
 (1, 69): u'Houston County, Alabama',
 (1, 71): u'Jackson County, Alabama',
 (1, 73): u'Jefferson County, Alabama',
 (1, 75): u'Lamar County, Alabama',
 (1, 77): u'Lauderdale County, Alabama',
 (1, 79): u'Lawrence County, Alabama',
 (1, 81): u'Lee County, Alabama',
 (1, 83): u'Limestone County, Alabama',
 (1, 85): u'Lowndes County, Alabama',
 (1, 87): u'Macon County, Alabama',
 (1, 89): u'Madison County, Alabama',
 (1, 91): u'Marengo County, Alabama',
 (1, 93): u'Marion County, Alabama',
 (1, 95): u'Marshall County, Alabama',
 (1, 97): u'Mobile County, Alabama',
 (1, 99): u'Monroe County, Alabama',
 (1, 101): u'Montgomery County, Alabama',
 (1, 103): u'Morgan County, Alabama',
 (1, 105): u'Perry County, Alabama',
 (1, 107): u'Pickens County, Alabama',
 (1, 109): u'Pike County, Alabama',
 (1, 111): u'Randolph County, Alabama',
 (1, 113): u'Russell County, Alabama',
 (1, 115): u'St. Clair County, Alabama',
 (1, 117): u'Shelby County, Alabama',
 (1, 119): u'Sumter County, Alabama',
 (1, 121): u'Talladega County, Alabama',
 (1, 123): u'Tallapoosa County, Alabama',
 (1, 125): u'Tuscaloosa County, Alabama',
 (1, 127): u'Walker County, Alabama',
 (1, 129): u'Washington County, Alabama',
 (1, 131): u'Wilcox County, Alabama',
 (1, 133): u'Winston County, Alabama',
 (2, 0):  u'Alaska',
 (2, 13): u'Aleutians East Borough, Alaska',
 (2, 16): u'Aleutians West Census Area, Alaska',
 (2, 20): u'Anchorage Municipality, Alaska',
 (2, 50): u'Bethel Census Area, Alaska',
 (2, 60): u'Bristol Bay Borough, Alaska',
 (2, 68): u'Denali Borough, Alaska',
 (2, 70): u'Dillingham Census Area, Alaska',
 (2, 90): u'Fairbanks North Star Borough, Alaska',
 (2, 100): u'Haines Borough, Alaska',
 (2, 105): u'Hoonah-Angoon Census Area, Alaska',
 (2, 110): u'Juneau City and Borough, Alaska',
 (2, 122): u'Kenai Peninsula Borough, Alaska',
 (2, 130): u'Ketchikan Gateway Borough, Alaska',
 (2, 150): u'Kodiak Island Borough, Alaska',
 (2, 164): u'Lake and Peninsula Borough, Alaska',
 (2, 170): u'Matanuska-Susitna Borough, Alaska',
 (2, 180): u'Nome Census Area, Alaska',
 (2, 185): u'North Slope Borough, Alaska',
 (2, 188): u'Northwest Arctic Borough, Alaska',
 (2, 195): u'Petersburg Census Area, Alaska',
 (2, 198): u'Prince of Wales-Hyder Census Area, Alaska',
 (2, 220): u'Sitka City and Borough, Alaska',
 (2, 230): u'Skagway Municipality, Alaska',
 (2, 240): u'Southeast Fairbanks Census Area, Alaska',
 (2, 261): u'Valdez-Cordova Census Area, Alaska',
 (2, 270): u'Wade Hampton Census Area, Alaska',
 (2, 275): u'Wrangell City and Borough, Alaska',
 (2, 282): u'Yakutat City and Borough, Alaska',
 (2, 290): u'Yukon-Koyukuk Census Area, Alaska',
 (4, 0): u'Arizona',
 (4, 1): u'Apache County, Arizona',
 (4, 3): u'Cochise County, Arizona',
 (4, 5): u'Coconino County, Arizona',
 (4, 7): u'Gila County, Arizona',
 (4, 9): u'Graham County, Arizona',
 (4, 11): u'Greenlee County, Arizona',
 (4, 12): u'La Paz County, Arizona',
 (4, 13): u'Maricopa County, Arizona',
 (4, 15): u'Mohave County, Arizona',
 (4, 17): u'Navajo County, Arizona',
 (4, 19): u'Pima County, Arizona',
 (4, 21): u'Pinal County, Arizona',
 (4, 23): u'Santa Cruz County, Arizona',
 (4, 25): u'Yavapai County, Arizona',
 (4, 27): u'Yuma County, Arizona',
 (5, 0): u'Arkansas',
 (5, 1): u'Arkansas County, Arkansas',
 (5, 3): u'Ashley County, Arkansas',
 (5, 5): u'Baxter County, Arkansas',
 (5, 7): u'Benton County, Arkansas',
 (5, 9): u'Boone County, Arkansas',
 (5, 11): u'Bradley County, Arkansas',
 (5, 13): u'Calhoun County, Arkansas',
 (5, 15): u'Carroll County, Arkansas',
 (5, 17): u'Chicot County, Arkansas',
 (5, 19): u'Clark County, Arkansas',
 (5, 21): u'Clay County, Arkansas',
 (5, 23): u'Cleburne County, Arkansas',
 (5, 25): u'Cleveland County, Arkansas',
 (5, 27): u'Columbia County, Arkansas',
 (5, 29): u'Conway County, Arkansas',
 (5, 31): u'Craighead County, Arkansas',
 (5, 33): u'Crawford County, Arkansas',
 (5, 35): u'Crittenden County, Arkansas',
 (5, 37): u'Cross County, Arkansas',
 (5, 39): u'Dallas County, Arkansas',
 (5, 41): u'Desha County, Arkansas',
 (5, 43): u'Drew County, Arkansas',
 (5, 45): u'Faulkner County, Arkansas',
 (5, 47): u'Franklin County, Arkansas',
 (5, 49): u'Fulton County, Arkansas',
 (5, 51): u'Garland County, Arkansas',
 (5, 53): u'Grant County, Arkansas',
 (5, 55): u'Greene County, Arkansas',
 (5, 57): u'Hempstead County, Arkansas',
 (5, 59): u'Hot Spring County, Arkansas',
 (5, 61): u'Howard County, Arkansas',
 (5, 63): u'Independence County, Arkansas',
 (5, 65): u'Izard County, Arkansas',
 (5, 67): u'Jackson County, Arkansas',
 (5, 69): u'Jefferson County, Arkansas',
 (5, 71): u'Johnson County, Arkansas',
 (5, 73): u'Lafayette County, Arkansas',
 (5, 75): u'Lawrence County, Arkansas',
 (5, 77): u'Lee County, Arkansas',
 (5, 79): u'Lincoln County, Arkansas',
 (5, 81): u'Little River County, Arkansas',
 (5, 83): u'Logan County, Arkansas',
 (5, 85): u'Lonoke County, Arkansas',
 (5, 87): u'Madison County, Arkansas',
 (5, 89): u'Marion County, Arkansas',
 (5, 91): u'Miller County, Arkansas',
 (5, 93): u'Mississippi County, Arkansas',
 (5, 95): u'Monroe County, Arkansas',
 (5, 97): u'Montgomery County, Arkansas',
 (5, 99): u'Nevada County, Arkansas',
 (5, 101): u'Newton County, Arkansas',
 (5, 103): u'Ouachita County, Arkansas',
 (5, 105): u'Perry County, Arkansas',
 (5, 107): u'Phillips County, Arkansas',
 (5, 109): u'Pike County, Arkansas',
 (5, 111): u'Poinsett County, Arkansas',
 (5, 113): u'Polk County, Arkansas',
 (5, 115): u'Pope County, Arkansas',
 (5, 117): u'Prairie County, Arkansas',
 (5, 119): u'Pulaski County, Arkansas',
 (5, 121): u'Randolph County, Arkansas',
 (5, 123): u'St. Francis County, Arkansas',
 (5, 125): u'Saline County, Arkansas',
 (5, 127): u'Scott County, Arkansas',
 (5, 129): u'Searcy County, Arkansas',
 (5, 131): u'Sebastian County, Arkansas',
 (5, 133): u'Sevier County, Arkansas',
 (5, 135): u'Sharp County, Arkansas',
 (5, 137): u'Stone County, Arkansas',
 (5, 139): u'Union County, Arkansas',
 (5, 141): u'Van Buren County, Arkansas',
 (5, 143): u'Washington County, Arkansas',
 (5, 145): u'White County, Arkansas',
 (5, 147): u'Woodruff County, Arkansas',
 (5, 149): u'Yell County, Arkansas',
 (6, 0): u'California',
 (6, 1): u'Alameda County, California',
 (6, 3): u'Alpine County, California',
 (6, 5): u'Amador County, California',
 (6, 7): u'Butte County, California',
 (6, 9): u'Calaveras County, California',
 (6, 11): u'Colusa County, California',
 (6, 13): u'Contra Costa County, California',
 (6, 15): u'Del Norte County, California',
 (6, 17): u'El Dorado County, California',
 (6, 19): u'Fresno County, California',
 (6, 21): u'Glenn County, California',
 (6, 23): u'Humboldt County, California',
 (6, 25): u'Imperial County, California',
 (6, 27): u'Inyo County, California',
 (6, 29): u'Kern County, California',
 (6, 31): u'Kings County, California',
 (6, 33): u'Lake County, California',
 (6, 35): u'Lassen County, California',
 (6, 37): u'Los Angeles County, California',
 (6, 39): u'Madera County, California',
 (6, 41): u'Marin County, California',
 (6, 43): u'Mariposa County, California',
 (6, 45): u'Mendocino County, California',
 (6, 47): u'Merced County, California',
 (6, 49): u'Modoc County, California',
 (6, 51): u'Mono County, California',
 (6, 53): u'Monterey County, California',
 (6, 55): u'Napa County, California',
 (6, 57): u'Nevada County, California',
 (6, 59): u'Orange County, California',
 (6, 61): u'Placer County, California',
 (6, 63): u'Plumas County, California',
 (6, 65): u'Riverside County, California',
 (6, 67): u'Sacramento County, California',
 (6, 69): u'San Benito County, California',
 (6, 71): u'San Bernardino County, California',
 (6, 73): u'San Diego County, California',
 (6, 75): u'San Francisco County, California',
 (6, 77): u'San Joaquin County, California',
 (6, 79): u'San Luis Obispo County, California',
 (6, 81): u'San Mateo County, California',
 (6, 83): u'Santa Barbara County, California',
 (6, 85): u'Santa Clara County, California',
 (6, 87): u'Santa Cruz County, California',
 (6, 89): u'Shasta County, California',
 (6, 91): u'Sierra County, California',
 (6, 93): u'Siskiyou County, California',
 (6, 95): u'Solano County, California',
 (6, 97): u'Sonoma County, California',
 (6, 99): u'Stanislaus County, California',
 (6, 101): u'Sutter County, California',
 (6, 103): u'Tehama County, California',
 (6, 105): u'Trinity County, California',
 (6, 107): u'Tulare County, California',
 (6, 109): u'Tuolumne County, California',
 (6, 111): u'Ventura County, California',
 (6, 113): u'Yolo County, California',
 (6, 115): u'Yuba County, California',
 (8, 0): u'Colorado',
 (8, 1): u'Adams County, Colorado',
 (8, 3): u'Alamosa County, Colorado',
 (8, 5): u'Arapahoe County, Colorado',
 (8, 7): u'Archuleta County, Colorado',
 (8, 9): u'Baca County, Colorado',
 (8, 11): u'Bent County, Colorado',
 (8, 13): u'Boulder County, Colorado',
 (8, 14): u'Broomfield County, Colorado',
 (8, 15): u'Chaffee County, Colorado',
 (8, 17): u'Cheyenne County, Colorado',
 (8, 19): u'Clear Creek County, Colorado',
 (8, 21): u'Conejos County, Colorado',
 (8, 23): u'Costilla County, Colorado',
 (8, 25): u'Crowley County, Colorado',
 (8, 27): u'Custer County, Colorado',
 (8, 29): u'Delta County, Colorado',
 (8, 31): u'Denver County, Colorado',
 (8, 33): u'Dolores County, Colorado',
 (8, 35): u'Douglas County, Colorado',
 (8, 37): u'Eagle County, Colorado',
 (8, 39): u'Elbert County, Colorado',
 (8, 41): u'El Paso County, Colorado',
 (8, 43): u'Fremont County, Colorado',
 (8, 45): u'Garfield County, Colorado',
 (8, 47): u'Gilpin County, Colorado',
 (8, 49): u'Grand County, Colorado',
 (8, 51): u'Gunnison County, Colorado',
 (8, 53): u'Hinsdale County, Colorado',
 (8, 55): u'Huerfano County, Colorado',
 (8, 57): u'Jackson County, Colorado',
 (8, 59): u'Jefferson County, Colorado',
 (8, 61): u'Kiowa County, Colorado',
 (8, 63): u'Kit Carson County, Colorado',
 (8, 65): u'Lake County, Colorado',
 (8, 67): u'La Plata County, Colorado',
 (8, 69): u'Larimer County, Colorado',
 (8, 71): u'Las Animas County, Colorado',
 (8, 73): u'Lincoln County, Colorado',
 (8, 75): u'Logan County, Colorado',
 (8, 77): u'Mesa County, Colorado',
 (8, 79): u'Mineral County, Colorado',
 (8, 81): u'Moffat County, Colorado',
 (8, 83): u'Montezuma County, Colorado',
 (8, 85): u'Montrose County, Colorado',
 (8, 87): u'Morgan County, Colorado',
 (8, 89): u'Otero County, Colorado',
 (8, 91): u'Ouray County, Colorado',
 (8, 93): u'Park County, Colorado',
 (8, 95): u'Phillips County, Colorado',
 (8, 97): u'Pitkin County, Colorado',
 (8, 99): u'Prowers County, Colorado',
 (8, 101): u'Pueblo County, Colorado',
 (8, 103): u'Rio Blanco County, Colorado',
 (8, 105): u'Rio Grande County, Colorado',
 (8, 107): u'Routt County, Colorado',
 (8, 109): u'Saguache County, Colorado',
 (8, 111): u'San Juan County, Colorado',
 (8, 113): u'San Miguel County, Colorado',
 (8, 115): u'Sedgwick County, Colorado',
 (8, 117): u'Summit County, Colorado',
 (8, 119): u'Teller County, Colorado',
 (8, 121): u'Washington County, Colorado',
 (8, 123): u'Weld County, Colorado',
 (8, 125): u'Yuma County, Colorado',
 (9, 0): u'Connecticut',
 (9, 1): u'Fairfield County, Connecticut',
 (9, 3): u'Hartford County, Connecticut',
 (9, 5): u'Litchfield County, Connecticut',
 (9, 7): u'Middlesex County, Connecticut',
 (9, 9): u'New Haven County, Connecticut',
 (9, 11): u'New London County, Connecticut',
 (9, 13): u'Tolland County, Connecticut',
 (9, 15): u'Windham County, Connecticut',
 (10, 0): u'Delaware',
 (10, 1): u'Kent County, Delaware',
 (10, 3): u'New Castle County, Delaware',
 (10, 5): u'Sussex County, Delaware',
 (11, 0): u'District of Columbia',
 (11, 1): u'District of Columbia',
 (12, 0): u'Florida',
 (12, 1): u'Alachua County, Florida',
 (12, 3): u'Baker County, Florida',
 (12, 5): u'Bay County, Florida',
 (12, 7): u'Bradford County, Florida',
 (12, 9): u'Brevard County, Florida',
 (12, 11): u'Broward County, Florida',
 (12, 13): u'Calhoun County, Florida',
 (12, 15): u'Charlotte County, Florida',
 (12, 17): u'Citrus County, Florida',
 (12, 19): u'Clay County, Florida',
 (12, 21): u'Collier County, Florida',
 (12, 23): u'Columbia County, Florida',
 (12, 27): u'DeSoto County, Florida',
 (12, 29): u'Dixie County, Florida',
 (12, 31): u'Duval County, Florida',
 (12, 33): u'Escambia County, Florida',
 (12, 35): u'Flagler County, Florida',
 (12, 37): u'Franklin County, Florida',
 (12, 39): u'Gadsden County, Florida',
 (12, 41): u'Gilchrist County, Florida',
 (12, 43): u'Glades County, Florida',
 (12, 45): u'Gulf County, Florida',
 (12, 47): u'Hamilton County, Florida',
 (12, 49): u'Hardee County, Florida',
 (12, 51): u'Hendry County, Florida',
 (12, 53): u'Hernando County, Florida',
 (12, 55): u'Highlands County, Florida',
 (12, 57): u'Hillsborough County, Florida',
 (12, 59): u'Holmes County, Florida',
 (12, 61): u'Indian River County, Florida',
 (12, 63): u'Jackson County, Florida',
 (12, 65): u'Jefferson County, Florida',
 (12, 67): u'Lafayette County, Florida',
 (12, 69): u'Lake County, Florida',
 (12, 71): u'Lee County, Florida',
 (12, 73): u'Leon County, Florida',
 (12, 75): u'Levy County, Florida',
 (12, 77): u'Liberty County, Florida',
 (12, 79): u'Madison County, Florida',
 (12, 81): u'Manatee County, Florida',
 (12, 83): u'Marion County, Florida',
 (12, 85): u'Martin County, Florida',
 (12, 86): u'Miami-Dade County, Florida',
 (12, 87): u'Monroe County, Florida',
 (12, 89): u'Nassau County, Florida',
 (12, 91): u'Okaloosa County, Florida',
 (12, 93): u'Okeechobee County, Florida',
 (12, 95): u'Orange County, Florida',
 (12, 97): u'Osceola County, Florida',
 (12, 99): u'Palm Beach County, Florida',
 (12, 101): u'Pasco County, Florida',
 (12, 103): u'Pinellas County, Florida',
 (12, 105): u'Polk County, Florida',
 (12, 107): u'Putnam County, Florida',
 (12, 109): u'St. Johns County, Florida',
 (12, 111): u'St. Lucie County, Florida',
 (12, 113): u'Santa Rosa County, Florida',
 (12, 115): u'Sarasota County, Florida',
 (12, 117): u'Seminole County, Florida',
 (12, 119): u'Sumter County, Florida',
 (12, 121): u'Suwannee County, Florida',
 (12, 123): u'Taylor County, Florida',
 (12, 125): u'Union County, Florida',
 (12, 127): u'Volusia County, Florida',
 (12, 129): u'Wakulla County, Florida',
 (12, 131): u'Walton County, Florida',
 (12, 133): u'Washington County, Florida',
 (13, 0): u'Georgia',
 (13, 1): u'Appling County, Georgia',
 (13, 3): u'Atkinson County, Georgia',
 (13, 5): u'Bacon County, Georgia',
 (13, 7): u'Baker County, Georgia',
 (13, 9): u'Baldwin County, Georgia',
 (13, 11): u'Banks County, Georgia',
 (13, 13): u'Barrow County, Georgia',
 (13, 15): u'Bartow County, Georgia',
 (13, 17): u'Ben Hill County, Georgia',
 (13, 19): u'Berrien County, Georgia',
 (13, 21): u'Bibb County, Georgia',
 (13, 23): u'Bleckley County, Georgia',
 (13, 25): u'Brantley County, Georgia',
 (13, 27): u'Brooks County, Georgia',
 (13, 29): u'Bryan County, Georgia',
 (13, 31): u'Bulloch County, Georgia',
 (13, 33): u'Burke County, Georgia',
 (13, 35): u'Butts County, Georgia',
 (13, 37): u'Calhoun County, Georgia',
 (13, 39): u'Camden County, Georgia',
 (13, 43): u'Candler County, Georgia',
 (13, 45): u'Carroll County, Georgia',
 (13, 47): u'Catoosa County, Georgia',
 (13, 49): u'Charlton County, Georgia',
 (13, 51): u'Chatham County, Georgia',
 (13, 53): u'Chattahoochee County, Georgia',
 (13, 55): u'Chattooga County, Georgia',
 (13, 57): u'Cherokee County, Georgia',
 (13, 59): u'Clarke County, Georgia',
 (13, 61): u'Clay County, Georgia',
 (13, 63): u'Clayton County, Georgia',
 (13, 65): u'Clinch County, Georgia',
 (13, 67): u'Cobb County, Georgia',
 (13, 69): u'Coffee County, Georgia',
 (13, 71): u'Colquitt County, Georgia',
 (13, 73): u'Columbia County, Georgia',
 (13, 75): u'Cook County, Georgia',
 (13, 77): u'Coweta County, Georgia',
 (13, 79): u'Crawford County, Georgia',
 (13, 81): u'Crisp County, Georgia',
 (13, 83): u'Dade County, Georgia',
 (13, 85): u'Dawson County, Georgia',
 (13, 87): u'Decatur County, Georgia',
 (13, 89): u'DeKalb County, Georgia',
 (13, 91): u'Dodge County, Georgia',
 (13, 93): u'Dooly County, Georgia',
 (13, 95): u'Dougherty County, Georgia',
 (13, 97): u'Douglas County, Georgia',
 (13, 99): u'Early County, Georgia',
 (13, 101): u'Echols County, Georgia',
 (13, 103): u'Effingham County, Georgia',
 (13, 105): u'Elbert County, Georgia',
 (13, 107): u'Emanuel County, Georgia',
 (13, 109): u'Evans County, Georgia',
 (13, 111): u'Fannin County, Georgia',
 (13, 113): u'Fayette County, Georgia',
 (13, 115): u'Floyd County, Georgia',
 (13, 117): u'Forsyth County, Georgia',
 (13, 119): u'Franklin County, Georgia',
 (13, 121): u'Fulton County, Georgia',
 (13, 123): u'Gilmer County, Georgia',
 (13, 125): u'Glascock County, Georgia',
 (13, 127): u'Glynn County, Georgia',
 (13, 129): u'Gordon County, Georgia',
 (13, 131): u'Grady County, Georgia',
 (13, 133): u'Greene County, Georgia',
 (13, 135): u'Gwinnett County, Georgia',
 (13, 137): u'Habersham County, Georgia',
 (13, 139): u'Hall County, Georgia',
 (13, 141): u'Hancock County, Georgia',
 (13, 143): u'Haralson County, Georgia',
 (13, 145): u'Harris County, Georgia',
 (13, 147): u'Hart County, Georgia',
 (13, 149): u'Heard County, Georgia',
 (13, 151): u'Henry County, Georgia',
 (13, 153): u'Houston County, Georgia',
 (13, 155): u'Irwin County, Georgia',
 (13, 157): u'Jackson County, Georgia',
 (13, 159): u'Jasper County, Georgia',
 (13, 161): u'Jeff Davis County, Georgia',
 (13, 163): u'Jefferson County, Georgia',
 (13, 165): u'Jenkins County, Georgia',
 (13, 167): u'Johnson County, Georgia',
 (13, 169): u'Jones County, Georgia',
 (13, 171): u'Lamar County, Georgia',
 (13, 173): u'Lanier County, Georgia',
 (13, 175): u'Laurens County, Georgia',
 (13, 177): u'Lee County, Georgia',
 (13, 179): u'Liberty County, Georgia',
 (13, 181): u'Lincoln County, Georgia',
 (13, 183): u'Long County, Georgia',
 (13, 185): u'Lowndes County, Georgia',
 (13, 187): u'Lumpkin County, Georgia',
 (13, 189): u'McDuffie County, Georgia',
 (13, 191): u'McIntosh County, Georgia',
 (13, 193): u'Macon County, Georgia',
 (13, 195): u'Madison County, Georgia',
 (13, 197): u'Marion County, Georgia',
 (13, 199): u'Meriwether County, Georgia',
 (13, 201): u'Miller County, Georgia',
 (13, 205): u'Mitchell County, Georgia',
 (13, 207): u'Monroe County, Georgia',
 (13, 209): u'Montgomery County, Georgia',
 (13, 211): u'Morgan County, Georgia',
 (13, 213): u'Murray County, Georgia',
 (13, 215): u'Muscogee County, Georgia',
 (13, 217): u'Newton County, Georgia',
 (13, 219): u'Oconee County, Georgia',
 (13, 221): u'Oglethorpe County, Georgia',
 (13, 223): u'Paulding County, Georgia',
 (13, 225): u'Peach County, Georgia',
 (13, 227): u'Pickens County, Georgia',
 (13, 229): u'Pierce County, Georgia',
 (13, 231): u'Pike County, Georgia',
 (13, 233): u'Polk County, Georgia',
 (13, 235): u'Pulaski County, Georgia',
 (13, 237): u'Putnam County, Georgia',
 (13, 239): u'Quitman County, Georgia',
 (13, 241): u'Rabun County, Georgia',
 (13, 243): u'Randolph County, Georgia',
 (13, 245): u'Richmond County, Georgia',
 (13, 247): u'Rockdale County, Georgia',
 (13, 249): u'Schley County, Georgia',
 (13, 251): u'Screven County, Georgia',
 (13, 253): u'Seminole County, Georgia',
 (13, 255): u'Spalding County, Georgia',
 (13, 257): u'Stephens County, Georgia',
 (13, 259): u'Stewart County, Georgia',
 (13, 261): u'Sumter County, Georgia',
 (13, 263): u'Talbot County, Georgia',
 (13, 265): u'Taliaferro County, Georgia',
 (13, 267): u'Tattnall County, Georgia',
 (13, 269): u'Taylor County, Georgia',
 (13, 271): u'Telfair County, Georgia',
 (13, 273): u'Terrell County, Georgia',
 (13, 275): u'Thomas County, Georgia',
 (13, 277): u'Tift County, Georgia',
 (13, 279): u'Toombs County, Georgia',
 (13, 281): u'Towns County, Georgia',
 (13, 283): u'Treutlen County, Georgia',
 (13, 285): u'Troup County, Georgia',
 (13, 287): u'Turner County, Georgia',
 (13, 289): u'Twiggs County, Georgia',
 (13, 291): u'Union County, Georgia',
 (13, 293): u'Upson County, Georgia',
 (13, 295): u'Walker County, Georgia',
 (13, 297): u'Walton County, Georgia',
 (13, 299): u'Ware County, Georgia',
 (13, 301): u'Warren County, Georgia',
 (13, 303): u'Washington County, Georgia',
 (13, 305): u'Wayne County, Georgia',
 (13, 307): u'Webster County, Georgia',
 (13, 309): u'Wheeler County, Georgia',
 (13, 311): u'White County, Georgia',
 (13, 313): u'Whitfield County, Georgia',
 (13, 315): u'Wilcox County, Georgia',
 (13, 317): u'Wilkes County, Georgia',
 (13, 319): u'Wilkinson County, Georgia',
 (13, 321): u'Worth County, Georgia',
 (15, 0): u'Hawaii',
 (15, 1): u'Hawaii County, Hawaii',
 (15, 3): u'Honolulu County, Hawaii',
 (15, 5): u'Kalawao County, Hawaii',
 (15, 7): u'Kauai County, Hawaii',
 (15, 9): u'Maui County, Hawaii',
 (16, 0): u'Idaho',
 (16, 1): u'Ada County, Idaho',
 (16, 3): u'Adams County, Idaho',
 (16, 5): u'Bannock County, Idaho',
 (16, 7): u'Bear Lake County, Idaho',
 (16, 9): u'Benewah County, Idaho',
 (16, 11): u'Bingham County, Idaho',
 (16, 13): u'Blaine County, Idaho',
 (16, 15): u'Boise County, Idaho',
 (16, 17): u'Bonner County, Idaho',
 (16, 19): u'Bonneville County, Idaho',
 (16, 21): u'Boundary County, Idaho',
 (16, 23): u'Butte County, Idaho',
 (16, 25): u'Camas County, Idaho',
 (16, 27): u'Canyon County, Idaho',
 (16, 29): u'Caribou County, Idaho',
 (16, 31): u'Cassia County, Idaho',
 (16, 33): u'Clark County, Idaho',
 (16, 35): u'Clearwater County, Idaho',
 (16, 37): u'Custer County, Idaho',
 (16, 39): u'Elmore County, Idaho',
 (16, 41): u'Franklin County, Idaho',
 (16, 43): u'Fremont County, Idaho',
 (16, 45): u'Gem County, Idaho',
 (16, 47): u'Gooding County, Idaho',
 (16, 49): u'Idaho County, Idaho',
 (16, 51): u'Jefferson County, Idaho',
 (16, 53): u'Jerome County, Idaho',
 (16, 55): u'Kootenai County, Idaho',
 (16, 57): u'Latah County, Idaho',
 (16, 59): u'Lemhi County, Idaho',
 (16, 61): u'Lewis County, Idaho',
 (16, 63): u'Lincoln County, Idaho',
 (16, 65): u'Madison County, Idaho',
 (16, 67): u'Minidoka County, Idaho',
 (16, 69): u'Nez Perce County, Idaho',
 (16, 71): u'Oneida County, Idaho',
 (16, 73): u'Owyhee County, Idaho',
 (16, 75): u'Payette County, Idaho',
 (16, 77): u'Power County, Idaho',
 (16, 79): u'Shoshone County, Idaho',
 (16, 81): u'Teton County, Idaho',
 (16, 83): u'Twin Falls County, Idaho',
 (16, 85): u'Valley County, Idaho',
 (16, 87): u'Washington County, Idaho',
 (17, 0): u'Illinois',
 (17, 1): u'Adams County, Illinois',
 (17, 3): u'Alexander County, Illinois',
 (17, 5): u'Bond County, Illinois',
 (17, 7): u'Boone County, Illinois',
 (17, 9): u'Brown County, Illinois',
 (17, 11): u'Bureau County, Illinois',
 (17, 13): u'Calhoun County, Illinois',
 (17, 15): u'Carroll County, Illinois',
 (17, 17): u'Cass County, Illinois',
 (17, 19): u'Champaign County, Illinois',
 (17, 21): u'Christian County, Illinois',
 (17, 23): u'Clark County, Illinois',
 (17, 25): u'Clay County, Illinois',
 (17, 27): u'Clinton County, Illinois',
 (17, 29): u'Coles County, Illinois',
 (17, 31): u'Cook County, Illinois',
 (17, 33): u'Crawford County, Illinois',
 (17, 35): u'Cumberland County, Illinois',
 (17, 37): u'DeKalb County, Illinois',
 (17, 39): u'De Witt County, Illinois',
 (17, 41): u'Douglas County, Illinois',
 (17, 43): u'DuPage County, Illinois',
 (17, 45): u'Edgar County, Illinois',
 (17, 47): u'Edwards County, Illinois',
 (17, 49): u'Effingham County, Illinois',
 (17, 51): u'Fayette County, Illinois',
 (17, 53): u'Ford County, Illinois',
 (17, 55): u'Franklin County, Illinois',
 (17, 57): u'Fulton County, Illinois',
 (17, 59): u'Gallatin County, Illinois',
 (17, 61): u'Greene County, Illinois',
 (17, 63): u'Grundy County, Illinois',
 (17, 65): u'Hamilton County, Illinois',
 (17, 67): u'Hancock County, Illinois',
 (17, 69): u'Hardin County, Illinois',
 (17, 71): u'Henderson County, Illinois',
 (17, 73): u'Henry County, Illinois',
 (17, 75): u'Iroquois County, Illinois',
 (17, 77): u'Jackson County, Illinois',
 (17, 79): u'Jasper County, Illinois',
 (17, 81): u'Jefferson County, Illinois',
 (17, 83): u'Jersey County, Illinois',
 (17, 85): u'Jo Daviess County, Illinois',
 (17, 87): u'Johnson County, Illinois',
 (17, 89): u'Kane County, Illinois',
 (17, 91): u'Kankakee County, Illinois',
 (17, 93): u'Kendall County, Illinois',
 (17, 95): u'Knox County, Illinois',
 (17, 97): u'Lake County, Illinois',
 (17, 99): u'LaSalle County, Illinois',
 (17, 101): u'Lawrence County, Illinois',
 (17, 103): u'Lee County, Illinois',
 (17, 105): u'Livingston County, Illinois',
 (17, 107): u'Logan County, Illinois',
 (17, 109): u'McDonough County, Illinois',
 (17, 111): u'McHenry County, Illinois',
 (17, 113): u'McLean County, Illinois',
 (17, 115): u'Macon County, Illinois',
 (17, 117): u'Macoupin County, Illinois',
 (17, 119): u'Madison County, Illinois',
 (17, 121): u'Marion County, Illinois',
 (17, 123): u'Marshall County, Illinois',
 (17, 125): u'Mason County, Illinois',
 (17, 127): u'Massac County, Illinois',
 (17, 129): u'Menard County, Illinois',
 (17, 131): u'Mercer County, Illinois',
 (17, 133): u'Monroe County, Illinois',
 (17, 135): u'Montgomery County, Illinois',
 (17, 137): u'Morgan County, Illinois',
 (17, 139): u'Moultrie County, Illinois',
 (17, 141): u'Ogle County, Illinois',
 (17, 143): u'Peoria County, Illinois',
 (17, 145): u'Perry County, Illinois',
 (17, 147): u'Piatt County, Illinois',
 (17, 149): u'Pike County, Illinois',
 (17, 151): u'Pope County, Illinois',
 (17, 153): u'Pulaski County, Illinois',
 (17, 155): u'Putnam County, Illinois',
 (17, 157): u'Randolph County, Illinois',
 (17, 159): u'Richland County, Illinois',
 (17, 161): u'Rock Island County, Illinois',
 (17, 163): u'St. Clair County, Illinois',
 (17, 165): u'Saline County, Illinois',
 (17, 167): u'Sangamon County, Illinois',
 (17, 169): u'Schuyler County, Illinois',
 (17, 171): u'Scott County, Illinois',
 (17, 173): u'Shelby County, Illinois',
 (17, 175): u'Stark County, Illinois',
 (17, 177): u'Stephenson County, Illinois',
 (17, 179): u'Tazewell County, Illinois',
 (17, 181): u'Union County, Illinois',
 (17, 183): u'Vermilion County, Illinois',
 (17, 185): u'Wabash County, Illinois',
 (17, 187): u'Warren County, Illinois',
 (17, 189): u'Washington County, Illinois',
 (17, 191): u'Wayne County, Illinois',
 (17, 193): u'White County, Illinois',
 (17, 195): u'Whiteside County, Illinois',
 (17, 197): u'Will County, Illinois',
 (17, 199): u'Williamson County, Illinois',
 (17, 201): u'Winnebago County, Illinois',
 (17, 203): u'Woodford County, Illinois',
 (18, 0): u'Indiana',
 (18, 1): u'Adams County, Indiana',
 (18, 3): u'Allen County, Indiana',
 (18, 5): u'Bartholomew County, Indiana',
 (18, 7): u'Benton County, Indiana',
 (18, 9): u'Blackford County, Indiana',
 (18, 11): u'Boone County, Indiana',
 (18, 13): u'Brown County, Indiana',
 (18, 15): u'Carroll County, Indiana',
 (18, 17): u'Cass County, Indiana',
 (18, 19): u'Clark County, Indiana',
 (18, 21): u'Clay County, Indiana',
 (18, 23): u'Clinton County, Indiana',
 (18, 25): u'Crawford County, Indiana',
 (18, 27): u'Daviess County, Indiana',
 (18, 29): u'Dearborn County, Indiana',
 (18, 31): u'Decatur County, Indiana',
 (18, 33): u'DeKalb County, Indiana',
 (18, 35): u'Delaware County, Indiana',
 (18, 37): u'Dubois County, Indiana',
 (18, 39): u'Elkhart County, Indiana',
 (18, 41): u'Fayette County, Indiana',
 (18, 43): u'Floyd County, Indiana',
 (18, 45): u'Fountain County, Indiana',
 (18, 47): u'Franklin County, Indiana',
 (18, 49): u'Fulton County, Indiana',
 (18, 51): u'Gibson County, Indiana',
 (18, 53): u'Grant County, Indiana',
 (18, 55): u'Greene County, Indiana',
 (18, 57): u'Hamilton County, Indiana',
 (18, 59): u'Hancock County, Indiana',
 (18, 61): u'Harrison County, Indiana',
 (18, 63): u'Hendricks County, Indiana',
 (18, 65): u'Henry County, Indiana',
 (18, 67): u'Howard County, Indiana',
 (18, 69): u'Huntington County, Indiana',
 (18, 71): u'Jackson County, Indiana',
 (18, 73): u'Jasper County, Indiana',
 (18, 75): u'Jay County, Indiana',
 (18, 77): u'Jefferson County, Indiana',
 (18, 79): u'Jennings County, Indiana',
 (18, 81): u'Johnson County, Indiana',
 (18, 83): u'Knox County, Indiana',
 (18, 85): u'Kosciusko County, Indiana',
 (18, 87): u'LaGrange County, Indiana',
 (18, 89): u'Lake County, Indiana',
 (18, 91): u'LaPorte County, Indiana',
 (18, 93): u'Lawrence County, Indiana',
 (18, 95): u'Madison County, Indiana',
 (18, 97): u'Marion County, Indiana',
 (18, 99): u'Marshall County, Indiana',
 (18, 101): u'Martin County, Indiana',
 (18, 103): u'Miami County, Indiana',
 (18, 105): u'Monroe County, Indiana',
 (18, 107): u'Montgomery County, Indiana',
 (18, 109): u'Morgan County, Indiana',
 (18, 111): u'Newton County, Indiana',
 (18, 113): u'Noble County, Indiana',
 (18, 115): u'Ohio County, Indiana',
 (18, 117): u'Orange County, Indiana',
 (18, 119): u'Owen County, Indiana',
 (18, 121): u'Parke County, Indiana',
 (18, 123): u'Perry County, Indiana',
 (18, 125): u'Pike County, Indiana',
 (18, 127): u'Porter County, Indiana',
 (18, 129): u'Posey County, Indiana',
 (18, 131): u'Pulaski County, Indiana',
 (18, 133): u'Putnam County, Indiana',
 (18, 135): u'Randolph County, Indiana',
 (18, 137): u'Ripley County, Indiana',
 (18, 139): u'Rush County, Indiana',
 (18, 141): u'St. Joseph County, Indiana',
 (18, 143): u'Scott County, Indiana',
 (18, 145): u'Shelby County, Indiana',
 (18, 147): u'Spencer County, Indiana',
 (18, 149): u'Starke County, Indiana',
 (18, 151): u'Steuben County, Indiana',
 (18, 153): u'Sullivan County, Indiana',
 (18, 155): u'Switzerland County, Indiana',
 (18, 157): u'Tippecanoe County, Indiana',
 (18, 159): u'Tipton County, Indiana',
 (18, 161): u'Union County, Indiana',
 (18, 163): u'Vanderburgh County, Indiana',
 (18, 165): u'Vermillion County, Indiana',
 (18, 167): u'Vigo County, Indiana',
 (18, 169): u'Wabash County, Indiana',
 (18, 171): u'Warren County, Indiana',
 (18, 173): u'Warrick County, Indiana',
 (18, 175): u'Washington County, Indiana',
 (18, 177): u'Wayne County, Indiana',
 (18, 179): u'Wells County, Indiana',
 (18, 181): u'White County, Indiana',
 (18, 183): u'Whitley County, Indiana',
 (19, 0): u'Iowa',
 (19, 1): u'Adair County, Iowa',
 (19, 3): u'Adams County, Iowa',
 (19, 5): u'Allamakee County, Iowa',
 (19, 7): u'Appanoose County, Iowa',
 (19, 9): u'Audubon County, Iowa',
 (19, 11): u'Benton County, Iowa',
 (19, 13): u'Black Hawk County, Iowa',
 (19, 15): u'Boone County, Iowa',
 (19, 17): u'Bremer County, Iowa',
 (19, 19): u'Buchanan County, Iowa',
 (19, 21): u'Buena Vista County, Iowa',
 (19, 23): u'Butler County, Iowa',
 (19, 25): u'Calhoun County, Iowa',
 (19, 27): u'Carroll County, Iowa',
 (19, 29): u'Cass County, Iowa',
 (19, 31): u'Cedar County, Iowa',
 (19, 33): u'Cerro Gordo County, Iowa',
 (19, 35): u'Cherokee County, Iowa',
 (19, 37): u'Chickasaw County, Iowa',
 (19, 39): u'Clarke County, Iowa',
 (19, 41): u'Clay County, Iowa',
 (19, 43): u'Clayton County, Iowa',
 (19, 45): u'Clinton County, Iowa',
 (19, 47): u'Crawford County, Iowa',
 (19, 49): u'Dallas County, Iowa',
 (19, 51): u'Davis County, Iowa',
 (19, 53): u'Decatur County, Iowa',
 (19, 55): u'Delaware County, Iowa',
 (19, 57): u'Des Moines County, Iowa',
 (19, 59): u'Dickinson County, Iowa',
 (19, 61): u'Dubuque County, Iowa',
 (19, 63): u'Emmet County, Iowa',
 (19, 65): u'Fayette County, Iowa',
 (19, 67): u'Floyd County, Iowa',
 (19, 69): u'Franklin County, Iowa',
 (19, 71): u'Fremont County, Iowa',
 (19, 73): u'Greene County, Iowa',
 (19, 75): u'Grundy County, Iowa',
 (19, 77): u'Guthrie County, Iowa',
 (19, 79): u'Hamilton County, Iowa',
 (19, 81): u'Hancock County, Iowa',
 (19, 83): u'Hardin County, Iowa',
 (19, 85): u'Harrison County, Iowa',
 (19, 87): u'Henry County, Iowa',
 (19, 89): u'Howard County, Iowa',
 (19, 91): u'Humboldt County, Iowa',
 (19, 93): u'Ida County, Iowa',
 (19, 95): u'Iowa County, Iowa',
 (19, 97): u'Jackson County, Iowa',
 (19, 99): u'Jasper County, Iowa',
 (19, 101): u'Jefferson County, Iowa',
 (19, 103): u'Johnson County, Iowa',
 (19, 105): u'Jones County, Iowa',
 (19, 107): u'Keokuk County, Iowa',
 (19, 109): u'Kossuth County, Iowa',
 (19, 111): u'Lee County, Iowa',
 (19, 113): u'Linn County, Iowa',
 (19, 115): u'Louisa County, Iowa',
 (19, 117): u'Lucas County, Iowa',
 (19, 119): u'Lyon County, Iowa',
 (19, 121): u'Madison County, Iowa',
 (19, 123): u'Mahaska County, Iowa',
 (19, 125): u'Marion County, Iowa',
 (19, 127): u'Marshall County, Iowa',
 (19, 129): u'Mills County, Iowa',
 (19, 131): u'Mitchell County, Iowa',
 (19, 133): u'Monona County, Iowa',
 (19, 135): u'Monroe County, Iowa',
 (19, 137): u'Montgomery County, Iowa',
 (19, 139): u'Muscatine County, Iowa',
 (19, 141): u"O'Brien County, Iowa",
 (19, 143): u'Osceola County, Iowa',
 (19, 145): u'Page County, Iowa',
 (19, 147): u'Palo Alto County, Iowa',
 (19, 149): u'Plymouth County, Iowa',
 (19, 151): u'Pocahontas County, Iowa',
 (19, 153): u'Polk County, Iowa',
 (19, 155): u'Pottawattamie County, Iowa',
 (19, 157): u'Poweshiek County, Iowa',
 (19, 159): u'Ringgold County, Iowa',
 (19, 161): u'Sac County, Iowa',
 (19, 163): u'Scott County, Iowa',
 (19, 165): u'Shelby County, Iowa',
 (19, 167): u'Sioux County, Iowa',
 (19, 169): u'Story County, Iowa',
 (19, 171): u'Tama County, Iowa',
 (19, 173): u'Taylor County, Iowa',
 (19, 175): u'Union County, Iowa',
 (19, 177): u'Van Buren County, Iowa',
 (19, 179): u'Wapello County, Iowa',
 (19, 181): u'Warren County, Iowa',
 (19, 183): u'Washington County, Iowa',
 (19, 185): u'Wayne County, Iowa',
 (19, 187): u'Webster County, Iowa',
 (19, 189): u'Winnebago County, Iowa',
 (19, 191): u'Winneshiek County, Iowa',
 (19, 193): u'Woodbury County, Iowa',
 (19, 195): u'Worth County, Iowa',
 (19, 197): u'Wright County, Iowa',
 (20, 0): u'Kansas',
 (20, 1): u'Allen County, Kansas',
 (20, 3): u'Anderson County, Kansas',
 (20, 5): u'Atchison County, Kansas',
 (20, 7): u'Barber County, Kansas',
 (20, 9): u'Barton County, Kansas',
 (20, 11): u'Bourbon County, Kansas',
 (20, 13): u'Brown County, Kansas',
 (20, 15): u'Butler County, Kansas',
 (20, 17): u'Chase County, Kansas',
 (20, 19): u'Chautauqua County, Kansas',
 (20, 21): u'Cherokee County, Kansas',
 (20, 23): u'Cheyenne County, Kansas',
 (20, 25): u'Clark County, Kansas',
 (20, 27): u'Clay County, Kansas',
 (20, 29): u'Cloud County, Kansas',
 (20, 31): u'Coffey County, Kansas',
 (20, 33): u'Comanche County, Kansas',
 (20, 35): u'Cowley County, Kansas',
 (20, 37): u'Crawford County, Kansas',
 (20, 39): u'Decatur County, Kansas',
 (20, 41): u'Dickinson County, Kansas',
 (20, 43): u'Doniphan County, Kansas',
 (20, 45): u'Douglas County, Kansas',
 (20, 47): u'Edwards County, Kansas',
 (20, 49): u'Elk County, Kansas',
 (20, 51): u'Ellis County, Kansas',
 (20, 53): u'Ellsworth County, Kansas',
 (20, 55): u'Finney County, Kansas',
 (20, 57): u'Ford County, Kansas',
 (20, 59): u'Franklin County, Kansas',
 (20, 61): u'Geary County, Kansas',
 (20, 63): u'Gove County, Kansas',
 (20, 65): u'Graham County, Kansas',
 (20, 67): u'Grant County, Kansas',
 (20, 69): u'Gray County, Kansas',
 (20, 71): u'Greeley County, Kansas',
 (20, 73): u'Greenwood County, Kansas',
 (20, 75): u'Hamilton County, Kansas',
 (20, 77): u'Harper County, Kansas',
 (20, 79): u'Harvey County, Kansas',
 (20, 81): u'Haskell County, Kansas',
 (20, 83): u'Hodgeman County, Kansas',
 (20, 85): u'Jackson County, Kansas',
 (20, 87): u'Jefferson County, Kansas',
 (20, 89): u'Jewell County, Kansas',
 (20, 91): u'Johnson County, Kansas',
 (20, 93): u'Kearny County, Kansas',
 (20, 95): u'Kingman County, Kansas',
 (20, 97): u'Kiowa County, Kansas',
 (20, 99): u'Labette County, Kansas',
 (20, 101): u'Lane County, Kansas',
 (20, 103): u'Leavenworth County, Kansas',
 (20, 105): u'Lincoln County, Kansas',
 (20, 107): u'Linn County, Kansas',
 (20, 109): u'Logan County, Kansas',
 (20, 111): u'Lyon County, Kansas',
 (20, 113): u'McPherson County, Kansas',
 (20, 115): u'Marion County, Kansas',
 (20, 117): u'Marshall County, Kansas',
 (20, 119): u'Meade County, Kansas',
 (20, 121): u'Miami County, Kansas',
 (20, 123): u'Mitchell County, Kansas',
 (20, 125): u'Montgomery County, Kansas',
 (20, 127): u'Morris County, Kansas',
 (20, 129): u'Morton County, Kansas',
 (20, 131): u'Nemaha County, Kansas',
 (20, 133): u'Neosho County, Kansas',
 (20, 135): u'Ness County, Kansas',
 (20, 137): u'Norton County, Kansas',
 (20, 139): u'Osage County, Kansas',
 (20, 141): u'Osborne County, Kansas',
 (20, 143): u'Ottawa County, Kansas',
 (20, 145): u'Pawnee County, Kansas',
 (20, 147): u'Phillips County, Kansas',
 (20, 149): u'Pottawatomie County, Kansas',
 (20, 151): u'Pratt County, Kansas',
 (20, 153): u'Rawlins County, Kansas',
 (20, 155): u'Reno County, Kansas',
 (20, 157): u'Republic County, Kansas',
 (20, 159): u'Rice County, Kansas',
 (20, 161): u'Riley County, Kansas',
 (20, 163): u'Rooks County, Kansas',
 (20, 165): u'Rush County, Kansas',
 (20, 167): u'Russell County, Kansas',
 (20, 169): u'Saline County, Kansas',
 (20, 171): u'Scott County, Kansas',
 (20, 173): u'Sedgwick County, Kansas',
 (20, 175): u'Seward County, Kansas',
 (20, 177): u'Shawnee County, Kansas',
 (20, 179): u'Sheridan County, Kansas',
 (20, 181): u'Sherman County, Kansas',
 (20, 183): u'Smith County, Kansas',
 (20, 185): u'Stafford County, Kansas',
 (20, 187): u'Stanton County, Kansas',
 (20, 189): u'Stevens County, Kansas',
 (20, 191): u'Sumner County, Kansas',
 (20, 193): u'Thomas County, Kansas',
 (20, 195): u'Trego County, Kansas',
 (20, 197): u'Wabaunsee County, Kansas',
 (20, 199): u'Wallace County, Kansas',
 (20, 201): u'Washington County, Kansas',
 (20, 203): u'Wichita County, Kansas',
 (20, 205): u'Wilson County, Kansas',
 (20, 207): u'Woodson County, Kansas',
 (20, 209): u'Wyandotte County, Kansas',
 (21, 0): u'Kentucky',
 (21, 1): u'Adair County, Kentucky',
 (21, 3): u'Allen County, Kentucky',
 (21, 5): u'Anderson County, Kentucky',
 (21, 7): u'Ballard County, Kentucky',
 (21, 9): u'Barren County, Kentucky',
 (21, 11): u'Bath County, Kentucky',
 (21, 13): u'Bell County, Kentucky',
 (21, 15): u'Boone County, Kentucky',
 (21, 17): u'Bourbon County, Kentucky',
 (21, 19): u'Boyd County, Kentucky',
 (21, 21): u'Boyle County, Kentucky',
 (21, 23): u'Bracken County, Kentucky',
 (21, 25): u'Breathitt County, Kentucky',
 (21, 27): u'Breckinridge County, Kentucky',
 (21, 29): u'Bullitt County, Kentucky',
 (21, 31): u'Butler County, Kentucky',
 (21, 33): u'Caldwell County, Kentucky',
 (21, 35): u'Calloway County, Kentucky',
 (21, 37): u'Campbell County, Kentucky',
 (21, 39): u'Carlisle County, Kentucky',
 (21, 41): u'Carroll County, Kentucky',
 (21, 43): u'Carter County, Kentucky',
 (21, 45): u'Casey County, Kentucky',
 (21, 47): u'Christian County, Kentucky',
 (21, 49): u'Clark County, Kentucky',
 (21, 51): u'Clay County, Kentucky',
 (21, 53): u'Clinton County, Kentucky',
 (21, 55): u'Crittenden County, Kentucky',
 (21, 57): u'Cumberland County, Kentucky',
 (21, 59): u'Daviess County, Kentucky',
 (21, 61): u'Edmonson County, Kentucky',
 (21, 63): u'Elliott County, Kentucky',
 (21, 65): u'Estill County, Kentucky',
 (21, 67): u'Fayette County, Kentucky',
 (21, 69): u'Fleming County, Kentucky',
 (21, 71): u'Floyd County, Kentucky',
 (21, 73): u'Franklin County, Kentucky',
 (21, 75): u'Fulton County, Kentucky',
 (21, 77): u'Gallatin County, Kentucky',
 (21, 79): u'Garrard County, Kentucky',
 (21, 81): u'Grant County, Kentucky',
 (21, 83): u'Graves County, Kentucky',
 (21, 85): u'Grayson County, Kentucky',
 (21, 87): u'Green County, Kentucky',
 (21, 89): u'Greenup County, Kentucky',
 (21, 91): u'Hancock County, Kentucky',
 (21, 93): u'Hardin County, Kentucky',
 (21, 95): u'Harlan County, Kentucky',
 (21, 97): u'Harrison County, Kentucky',
 (21, 99): u'Hart County, Kentucky',
 (21, 101): u'Henderson County, Kentucky',
 (21, 103): u'Henry County, Kentucky',
 (21, 105): u'Hickman County, Kentucky',
 (21, 107): u'Hopkins County, Kentucky',
 (21, 109): u'Jackson County, Kentucky',
 (21, 111): u'Jefferson County, Kentucky',
 (21, 113): u'Jessamine County, Kentucky',
 (21, 115): u'Johnson County, Kentucky',
 (21, 117): u'Kenton County, Kentucky',
 (21, 119): u'Knott County, Kentucky',
 (21, 121): u'Knox County, Kentucky',
 (21, 123): u'Larue County, Kentucky',
 (21, 125): u'Laurel County, Kentucky',
 (21, 127): u'Lawrence County, Kentucky',
 (21, 129): u'Lee County, Kentucky',
 (21, 131): u'Leslie County, Kentucky',
 (21, 133): u'Letcher County, Kentucky',
 (21, 135): u'Lewis County, Kentucky',
 (21, 137): u'Lincoln County, Kentucky',
 (21, 139): u'Livingston County, Kentucky',
 (21, 141): u'Logan County, Kentucky',
 (21, 143): u'Lyon County, Kentucky',
 (21, 145): u'McCracken County, Kentucky',
 (21, 147): u'McCreary County, Kentucky',
 (21, 149): u'McLean County, Kentucky',
 (21, 151): u'Madison County, Kentucky',
 (21, 153): u'Magoffin County, Kentucky',
 (21, 155): u'Marion County, Kentucky',
 (21, 157): u'Marshall County, Kentucky',
 (21, 159): u'Martin County, Kentucky',
 (21, 161): u'Mason County, Kentucky',
 (21, 163): u'Meade County, Kentucky',
 (21, 165): u'Menifee County, Kentucky',
 (21, 167): u'Mercer County, Kentucky',
 (21, 169): u'Metcalfe County, Kentucky',
 (21, 171): u'Monroe County, Kentucky',
 (21, 173): u'Montgomery County, Kentucky',
 (21, 175): u'Morgan County, Kentucky',
 (21, 177): u'Muhlenberg County, Kentucky',
 (21, 179): u'Nelson County, Kentucky',
 (21, 181): u'Nicholas County, Kentucky',
 (21, 183): u'Ohio County, Kentucky',
 (21, 185): u'Oldham County, Kentucky',
 (21, 187): u'Owen County, Kentucky',
 (21, 189): u'Owsley County, Kentucky',
 (21, 191): u'Pendleton County, Kentucky',
 (21, 193): u'Perry County, Kentucky',
 (21, 195): u'Pike County, Kentucky',
 (21, 197): u'Powell County, Kentucky',
 (21, 199): u'Pulaski County, Kentucky',
 (21, 201): u'Robertson County, Kentucky',
 (21, 203): u'Rockcastle County, Kentucky',
 (21, 205): u'Rowan County, Kentucky',
 (21, 207): u'Russell County, Kentucky',
 (21, 209): u'Scott County, Kentucky',
 (21, 211): u'Shelby County, Kentucky',
 (21, 213): u'Simpson County, Kentucky',
 (21, 215): u'Spencer County, Kentucky',
 (21, 217): u'Taylor County, Kentucky',
 (21, 219): u'Todd County, Kentucky',
 (21, 221): u'Trigg County, Kentucky',
 (21, 223): u'Trimble County, Kentucky',
 (21, 225): u'Union County, Kentucky',
 (21, 227): u'Warren County, Kentucky',
 (21, 229): u'Washington County, Kentucky',
 (21, 231): u'Wayne County, Kentucky',
 (21, 233): u'Webster County, Kentucky',
 (21, 235): u'Whitley County, Kentucky',
 (21, 237): u'Wolfe County, Kentucky',
 (21, 239): u'Woodford County, Kentucky',
 (22, 0): u'Louisiana',
 (22, 1): u'Acadia Parish, Louisiana',
 (22, 3): u'Allen Parish, Louisiana',
 (22, 5): u'Ascension Parish, Louisiana',
 (22, 7): u'Assumption Parish, Louisiana',
 (22, 9): u'Avoyelles Parish, Louisiana',
 (22, 11): u'Beauregard Parish, Louisiana',
 (22, 13): u'Bienville Parish, Louisiana',
 (22, 15): u'Bossier Parish, Louisiana',
 (22, 17): u'Caddo Parish, Louisiana',
 (22, 19): u'Calcasieu Parish, Louisiana',
 (22, 21): u'Caldwell Parish, Louisiana',
 (22, 23): u'Cameron Parish, Louisiana',
 (22, 25): u'Catahoula Parish, Louisiana',
 (22, 27): u'Claiborne Parish, Louisiana',
 (22, 29): u'Concordia Parish, Louisiana',
 (22, 31): u'De Soto Parish, Louisiana',
 (22, 33): u'East Baton Rouge Parish, Louisiana',
 (22, 35): u'East Carroll Parish, Louisiana',
 (22, 37): u'East Feliciana Parish, Louisiana',
 (22, 39): u'Evangeline Parish, Louisiana',
 (22, 41): u'Franklin Parish, Louisiana',
 (22, 43): u'Grant Parish, Louisiana',
 (22, 45): u'Iberia Parish, Louisiana',
 (22, 47): u'Iberville Parish, Louisiana',
 (22, 49): u'Jackson Parish, Louisiana',
 (22, 51): u'Jefferson Parish, Louisiana',
 (22, 53): u'Jefferson Davis Parish, Louisiana',
 (22, 55): u'Lafayette Parish, Louisiana',
 (22, 57): u'Lafourche Parish, Louisiana',
 (22, 59): u'La Salle Parish, Louisiana',
 (22, 61): u'Lincoln Parish, Louisiana',
 (22, 63): u'Livingston Parish, Louisiana',
 (22, 65): u'Madison Parish, Louisiana',
 (22, 67): u'Morehouse Parish, Louisiana',
 (22, 69): u'Natchitoches Parish, Louisiana',
 (22, 71): u'Orleans Parish, Louisiana',
 (22, 73): u'Ouachita Parish, Louisiana',
 (22, 75): u'Plaquemines Parish, Louisiana',
 (22, 77): u'Pointe Coupee Parish, Louisiana',
 (22, 79): u'Rapides Parish, Louisiana',
 (22, 81): u'Red River Parish, Louisiana',
 (22, 83): u'Richland Parish, Louisiana',
 (22, 85): u'Sabine Parish, Louisiana',
 (22, 87): u'St. Bernard Parish, Louisiana',
 (22, 89): u'St. Charles Parish, Louisiana',
 (22, 91): u'St. Helena Parish, Louisiana',
 (22, 93): u'St. James Parish, Louisiana',
 (22, 95): u'St. John the Baptist Parish, Louisiana',
 (22, 97): u'St. Landry Parish, Louisiana',
 (22, 99): u'St. Martin Parish, Louisiana',
 (22, 101): u'St. Mary Parish, Louisiana',
 (22, 103): u'St. Tammany Parish, Louisiana',
 (22, 105): u'Tangipahoa Parish, Louisiana',
 (22, 107): u'Tensas Parish, Louisiana',
 (22, 109): u'Terrebonne Parish, Louisiana',
 (22, 111): u'Union Parish, Louisiana',
 (22, 113): u'Vermilion Parish, Louisiana',
 (22, 115): u'Vernon Parish, Louisiana',
 (22, 117): u'Washington Parish, Louisiana',
 (22, 119): u'Webster Parish, Louisiana',
 (22, 121): u'West Baton Rouge Parish, Louisiana',
 (22, 123): u'West Carroll Parish, Louisiana',
 (22, 125): u'West Feliciana Parish, Louisiana',
 (22, 127): u'Winn Parish, Louisiana',
 (23, 0): u'Maine',
 (23, 1): u'Androscoggin County, Maine',
 (23, 3): u'Aroostook County, Maine',
 (23, 5): u'Cumberland County, Maine',
 (23, 7): u'Franklin County, Maine',
 (23, 9): u'Hancock County, Maine',
 (23, 11): u'Kennebec County, Maine',
 (23, 13): u'Knox County, Maine',
 (23, 15): u'Lincoln County, Maine',
 (23, 17): u'Oxford County, Maine',
 (23, 19): u'Penobscot County, Maine',
 (23, 21): u'Piscataquis County, Maine',
 (23, 23): u'Sagadahoc County, Maine',
 (23, 25): u'Somerset County, Maine',
 (23, 27): u'Waldo County, Maine',
 (23, 29): u'Washington County, Maine',
 (23, 31): u'York County, Maine',
 (24, 0): u'Maryland',
 (24, 1): u'Allegany County, Maryland',
 (24, 3): u'Anne Arundel County, Maryland',
 (24, 5): u'Baltimore County, Maryland',
 (24, 9): u'Calvert County, Maryland',
 (24, 11): u'Caroline County, Maryland',
 (24, 13): u'Carroll County, Maryland',
 (24, 15): u'Cecil County, Maryland',
 (24, 17): u'Charles County, Maryland',
 (24, 19): u'Dorchester County, Maryland',
 (24, 21): u'Frederick County, Maryland',
 (24, 23): u'Garrett County, Maryland',
 (24, 25): u'Harford County, Maryland',
 (24, 27): u'Howard County, Maryland',
 (24, 29): u'Kent County, Maryland',
 (24, 31): u'Montgomery County, Maryland',
 (24, 33): u"Prince George's County, Maryland",
 (24, 35): u"Queen Anne's County, Maryland",
 (24, 37): u"St. Mary's County, Maryland",
 (24, 39): u'Somerset County, Maryland',
 (24, 41): u'Talbot County, Maryland',
 (24, 43): u'Washington County, Maryland',
 (24, 45): u'Wicomico County, Maryland',
 (24, 47): u'Worcester County, Maryland',
 (24, 510): u'Baltimore city, Maryland',
 (25, 0): u'Massachusetts',
 (25, 1): u'Barnstable County, Massachusetts',
 (25, 3): u'Berkshire County, Massachusetts',
 (25, 5): u'Bristol County, Massachusetts',
 (25, 7): u'Dukes County, Massachusetts',
 (25, 9): u'Essex County, Massachusetts',
 (25, 11): u'Franklin County, Massachusetts',
 (25, 13): u'Hampden County, Massachusetts',
 (25, 15): u'Hampshire County, Massachusetts',
 (25, 17): u'Middlesex County, Massachusetts',
 (25, 19): u'Nantucket County, Massachusetts',
 (25, 21): u'Norfolk County, Massachusetts',
 (25, 23): u'Plymouth County, Massachusetts',
 (25, 25): u'Suffolk County, Massachusetts',
 (25, 27): u'Worcester County, Massachusetts',
 (26, 0): u'Michigan',
 (26, 1): u'Alcona County, Michigan',
 (26, 3): u'Alger County, Michigan',
 (26, 5): u'Allegan County, Michigan',
 (26, 7): u'Alpena County, Michigan',
 (26, 9): u'Antrim County, Michigan',
 (26, 11): u'Arenac County, Michigan',
 (26, 13): u'Baraga County, Michigan',
 (26, 15): u'Barry County, Michigan',
 (26, 17): u'Bay County, Michigan',
 (26, 19): u'Benzie County, Michigan',
 (26, 21): u'Berrien County, Michigan',
 (26, 23): u'Branch County, Michigan',
 (26, 25): u'Calhoun County, Michigan',
 (26, 27): u'Cass County, Michigan',
 (26, 29): u'Charlevoix County, Michigan',
 (26, 31): u'Cheboygan County, Michigan',
 (26, 33): u'Chippewa County, Michigan',
 (26, 35): u'Clare County, Michigan',
 (26, 37): u'Clinton County, Michigan',
 (26, 39): u'Crawford County, Michigan',
 (26, 41): u'Delta County, Michigan',
 (26, 43): u'Dickinson County, Michigan',
 (26, 45): u'Eaton County, Michigan',
 (26, 47): u'Emmet County, Michigan',
 (26, 49): u'Genesee County, Michigan',
 (26, 51): u'Gladwin County, Michigan',
 (26, 53): u'Gogebic County, Michigan',
 (26, 55): u'Grand Traverse County, Michigan',
 (26, 57): u'Gratiot County, Michigan',
 (26, 59): u'Hillsdale County, Michigan',
 (26, 61): u'Houghton County, Michigan',
 (26, 63): u'Huron County, Michigan',
 (26, 65): u'Ingham County, Michigan',
 (26, 67): u'Ionia County, Michigan',
 (26, 69): u'Iosco County, Michigan',
 (26, 71): u'Iron County, Michigan',
 (26, 73): u'Isabella County, Michigan',
 (26, 75): u'Jackson County, Michigan',
 (26, 77): u'Kalamazoo County, Michigan',
 (26, 79): u'Kalkaska County, Michigan',
 (26, 81): u'Kent County, Michigan',
 (26, 83): u'Keweenaw County, Michigan',
 (26, 85): u'Lake County, Michigan',
 (26, 87): u'Lapeer County, Michigan',
 (26, 89): u'Leelanau County, Michigan',
 (26, 91): u'Lenawee County, Michigan',
 (26, 93): u'Livingston County, Michigan',
 (26, 95): u'Luce County, Michigan',
 (26, 97): u'Mackinac County, Michigan',
 (26, 99): u'Macomb County, Michigan',
 (26, 101): u'Manistee County, Michigan',
 (26, 103): u'Marquette County, Michigan',
 (26, 105): u'Mason County, Michigan',
 (26, 107): u'Mecosta County, Michigan',
 (26, 109): u'Menominee County, Michigan',
 (26, 111): u'Midland County, Michigan',
 (26, 113): u'Missaukee County, Michigan',
 (26, 115): u'Monroe County, Michigan',
 (26, 117): u'Montcalm County, Michigan',
 (26, 119): u'Montmorency County, Michigan',
 (26, 121): u'Muskegon County, Michigan',
 (26, 123): u'Newaygo County, Michigan',
 (26, 125): u'Oakland County, Michigan',
 (26, 127): u'Oceana County, Michigan',
 (26, 129): u'Ogemaw County, Michigan',
 (26, 131): u'Ontonagon County, Michigan',
 (26, 133): u'Osceola County, Michigan',
 (26, 135): u'Oscoda County, Michigan',
 (26, 137): u'Otsego County, Michigan',
 (26, 139): u'Ottawa County, Michigan',
 (26, 141): u'Presque Isle County, Michigan',
 (26, 143): u'Roscommon County, Michigan',
 (26, 145): u'Saginaw County, Michigan',
 (26, 147): u'St. Clair County, Michigan',
 (26, 149): u'St. Joseph County, Michigan',
 (26, 151): u'Sanilac County, Michigan',
 (26, 153): u'Schoolcraft County, Michigan',
 (26, 155): u'Shiawassee County, Michigan',
 (26, 157): u'Tuscola County, Michigan',
 (26, 159): u'Van Buren County, Michigan',
 (26, 161): u'Washtenaw County, Michigan',
 (26, 163): u'Wayne County, Michigan',
 (26, 165): u'Wexford County, Michigan',
 (27, 0): u'Minnesota',
 (27, 1): u'Aitkin County, Minnesota',
 (27, 3): u'Anoka County, Minnesota',
 (27, 5): u'Becker County, Minnesota',
 (27, 7): u'Beltrami County, Minnesota',
 (27, 9): u'Benton County, Minnesota',
 (27, 11): u'Big Stone County, Minnesota',
 (27, 13): u'Blue Earth County, Minnesota',
 (27, 15): u'Brown County, Minnesota',
 (27, 17): u'Carlton County, Minnesota',
 (27, 19): u'Carver County, Minnesota',
 (27, 21): u'Cass County, Minnesota',
 (27, 23): u'Chippewa County, Minnesota',
 (27, 25): u'Chisago County, Minnesota',
 (27, 27): u'Clay County, Minnesota',
 (27, 29): u'Clearwater County, Minnesota',
 (27, 31): u'Cook County, Minnesota',
 (27, 33): u'Cottonwood County, Minnesota',
 (27, 35): u'Crow Wing County, Minnesota',
 (27, 37): u'Dakota County, Minnesota',
 (27, 39): u'Dodge County, Minnesota',
 (27, 41): u'Douglas County, Minnesota',
 (27, 43): u'Faribault County, Minnesota',
 (27, 45): u'Fillmore County, Minnesota',
 (27, 47): u'Freeborn County, Minnesota',
 (27, 49): u'Goodhue County, Minnesota',
 (27, 51): u'Grant County, Minnesota',
 (27, 53): u'Hennepin County, Minnesota',
 (27, 55): u'Houston County, Minnesota',
 (27, 57): u'Hubbard County, Minnesota',
 (27, 59): u'Isanti County, Minnesota',
 (27, 61): u'Itasca County, Minnesota',
 (27, 63): u'Jackson County, Minnesota',
 (27, 65): u'Kanabec County, Minnesota',
 (27, 67): u'Kandiyohi County, Minnesota',
 (27, 69): u'Kittson County, Minnesota',
 (27, 71): u'Koochiching County, Minnesota',
 (27, 73): u'Lac qui Parle County, Minnesota',
 (27, 75): u'Lake County, Minnesota',
 (27, 77): u'Lake of the Woods County, Minnesota',
 (27, 79): u'Le Sueur County, Minnesota',
 (27, 81): u'Lincoln County, Minnesota',
 (27, 83): u'Lyon County, Minnesota',
 (27, 85): u'McLeod County, Minnesota',
 (27, 87): u'Mahnomen County, Minnesota',
 (27, 89): u'Marshall County, Minnesota',
 (27, 91): u'Martin County, Minnesota',
 (27, 93): u'Meeker County, Minnesota',
 (27, 95): u'Mille Lacs County, Minnesota',
 (27, 97): u'Morrison County, Minnesota',
 (27, 99): u'Mower County, Minnesota',
 (27, 101): u'Murray County, Minnesota',
 (27, 103): u'Nicollet County, Minnesota',
 (27, 105): u'Nobles County, Minnesota',
 (27, 107): u'Norman County, Minnesota',
 (27, 109): u'Olmsted County, Minnesota',
 (27, 111): u'Otter Tail County, Minnesota',
 (27, 113): u'Pennington County, Minnesota',
 (27, 115): u'Pine County, Minnesota',
 (27, 117): u'Pipestone County, Minnesota',
 (27, 119): u'Polk County, Minnesota',
 (27, 121): u'Pope County, Minnesota',
 (27, 123): u'Ramsey County, Minnesota',
 (27, 125): u'Red Lake County, Minnesota',
 (27, 127): u'Redwood County, Minnesota',
 (27, 129): u'Renville County, Minnesota',
 (27, 131): u'Rice County, Minnesota',
 (27, 133): u'Rock County, Minnesota',
 (27, 135): u'Roseau County, Minnesota',
 (27, 137): u'St. Louis County, Minnesota',
 (27, 139): u'Scott County, Minnesota',
 (27, 141): u'Sherburne County, Minnesota',
 (27, 143): u'Sibley County, Minnesota',
 (27, 145): u'Stearns County, Minnesota',
 (27, 147): u'Steele County, Minnesota',
 (27, 149): u'Stevens County, Minnesota',
 (27, 151): u'Swift County, Minnesota',
 (27, 153): u'Todd County, Minnesota',
 (27, 155): u'Traverse County, Minnesota',
 (27, 157): u'Wabasha County, Minnesota',
 (27, 159): u'Wadena County, Minnesota',
 (27, 161): u'Waseca County, Minnesota',
 (27, 163): u'Washington County, Minnesota',
 (27, 165): u'Watonwan County, Minnesota',
 (27, 167): u'Wilkin County, Minnesota',
 (27, 169): u'Winona County, Minnesota',
 (27, 171): u'Wright County, Minnesota',
 (27, 173): u'Yellow Medicine County, Minnesota',
 (28, 0): u'Mississippi',
 (28, 1): u'Adams County, Mississippi',
 (28, 3): u'Alcorn County, Mississippi',
 (28, 5): u'Amite County, Mississippi',
 (28, 7): u'Attala County, Mississippi',
 (28, 9): u'Benton County, Mississippi',
 (28, 11): u'Bolivar County, Mississippi',
 (28, 13): u'Calhoun County, Mississippi',
 (28, 15): u'Carroll County, Mississippi',
 (28, 17): u'Chickasaw County, Mississippi',
 (28, 19): u'Choctaw County, Mississippi',
 (28, 21): u'Claiborne County, Mississippi',
 (28, 23): u'Clarke County, Mississippi',
 (28, 25): u'Clay County, Mississippi',
 (28, 27): u'Coahoma County, Mississippi',
 (28, 29): u'Copiah County, Mississippi',
 (28, 31): u'Covington County, Mississippi',
 (28, 33): u'DeSoto County, Mississippi',
 (28, 35): u'Forrest County, Mississippi',
 (28, 37): u'Franklin County, Mississippi',
 (28, 39): u'George County, Mississippi',
 (28, 41): u'Greene County, Mississippi',
 (28, 43): u'Grenada County, Mississippi',
 (28, 45): u'Hancock County, Mississippi',
 (28, 47): u'Harrison County, Mississippi',
 (28, 49): u'Hinds County, Mississippi',
 (28, 51): u'Holmes County, Mississippi',
 (28, 53): u'Humphreys County, Mississippi',
 (28, 55): u'Issaquena County, Mississippi',
 (28, 57): u'Itawamba County, Mississippi',
 (28, 59): u'Jackson County, Mississippi',
 (28, 61): u'Jasper County, Mississippi',
 (28, 63): u'Jefferson County, Mississippi',
 (28, 65): u'Jefferson Davis County, Mississippi',
 (28, 67): u'Jones County, Mississippi',
 (28, 69): u'Kemper County, Mississippi',
 (28, 71): u'Lafayette County, Mississippi',
 (28, 73): u'Lamar County, Mississippi',
 (28, 75): u'Lauderdale County, Mississippi',
 (28, 77): u'Lawrence County, Mississippi',
 (28, 79): u'Leake County, Mississippi',
 (28, 81): u'Lee County, Mississippi',
 (28, 83): u'Leflore County, Mississippi',
 (28, 85): u'Lincoln County, Mississippi',
 (28, 87): u'Lowndes County, Mississippi',
 (28, 89): u'Madison County, Mississippi',
 (28, 91): u'Marion County, Mississippi',
 (28, 93): u'Marshall County, Mississippi',
 (28, 95): u'Monroe County, Mississippi',
 (28, 97): u'Montgomery County, Mississippi',
 (28, 99): u'Neshoba County, Mississippi',
 (28, 101): u'Newton County, Mississippi',
 (28, 103): u'Noxubee County, Mississippi',
 (28, 105): u'Oktibbeha County, Mississippi',
 (28, 107): u'Panola County, Mississippi',
 (28, 109): u'Pearl River County, Mississippi',
 (28, 111): u'Perry County, Mississippi',
 (28, 113): u'Pike County, Mississippi',
 (28, 115): u'Pontotoc County, Mississippi',
 (28, 117): u'Prentiss County, Mississippi',
 (28, 119): u'Quitman County, Mississippi',
 (28, 121): u'Rankin County, Mississippi',
 (28, 123): u'Scott County, Mississippi',
 (28, 125): u'Sharkey County, Mississippi',
 (28, 127): u'Simpson County, Mississippi',
 (28, 129): u'Smith County, Mississippi',
 (28, 131): u'Stone County, Mississippi',
 (28, 133): u'Sunflower County, Mississippi',
 (28, 135): u'Tallahatchie County, Mississippi',
 (28, 137): u'Tate County, Mississippi',
 (28, 139): u'Tippah County, Mississippi',
 (28, 141): u'Tishomingo County, Mississippi',
 (28, 143): u'Tunica County, Mississippi',
 (28, 145): u'Union County, Mississippi',
 (28, 147): u'Walthall County, Mississippi',
 (28, 149): u'Warren County, Mississippi',
 (28, 151): u'Washington County, Mississippi',
 (28, 153): u'Wayne County, Mississippi',
 (28, 155): u'Webster County, Mississippi',
 (28, 157): u'Wilkinson County, Mississippi',
 (28, 159): u'Winston County, Mississippi',
 (28, 161): u'Yalobusha County, Mississippi',
 (28, 163): u'Yazoo County, Mississippi',
 (29, 0): u'Missouri',
 (29, 1): u'Adair County, Missouri',
 (29, 3): u'Andrew County, Missouri',
 (29, 5): u'Atchison County, Missouri',
 (29, 7): u'Audrain County, Missouri',
 (29, 9): u'Barry County, Missouri',
 (29, 11): u'Barton County, Missouri',
 (29, 13): u'Bates County, Missouri',
 (29, 15): u'Benton County, Missouri',
 (29, 17): u'Bollinger County, Missouri',
 (29, 19): u'Boone County, Missouri',
 (29, 21): u'Buchanan County, Missouri',
 (29, 23): u'Butler County, Missouri',
 (29, 25): u'Caldwell County, Missouri',
 (29, 27): u'Callaway County, Missouri',
 (29, 29): u'Camden County, Missouri',
 (29, 31): u'Cape Girardeau County, Missouri',
 (29, 33): u'Carroll County, Missouri',
 (29, 35): u'Carter County, Missouri',
 (29, 37): u'Cass County, Missouri',
 (29, 39): u'Cedar County, Missouri',
 (29, 41): u'Chariton County, Missouri',
 (29, 43): u'Christian County, Missouri',
 (29, 45): u'Clark County, Missouri',
 (29, 47): u'Clay County, Missouri',
 (29, 49): u'Clinton County, Missouri',
 (29, 51): u'Cole County, Missouri',
 (29, 53): u'Cooper County, Missouri',
 (29, 55): u'Crawford County, Missouri',
 (29, 57): u'Dade County, Missouri',
 (29, 59): u'Dallas County, Missouri',
 (29, 61): u'Daviess County, Missouri',
 (29, 63): u'DeKalb County, Missouri',
 (29, 65): u'Dent County, Missouri',
 (29, 67): u'Douglas County, Missouri',
 (29, 69): u'Dunklin County, Missouri',
 (29, 71): u'Franklin County, Missouri',
 (29, 73): u'Gasconade County, Missouri',
 (29, 75): u'Gentry County, Missouri',
 (29, 77): u'Greene County, Missouri',
 (29, 79): u'Grundy County, Missouri',
 (29, 81): u'Harrison County, Missouri',
 (29, 83): u'Henry County, Missouri',
 (29, 85): u'Hickory County, Missouri',
 (29, 87): u'Holt County, Missouri',
 (29, 89): u'Howard County, Missouri',
 (29, 91): u'Howell County, Missouri',
 (29, 93): u'Iron County, Missouri',
 (29, 95): u'Jackson County, Missouri',
 (29, 97): u'Jasper County, Missouri',
 (29, 99): u'Jefferson County, Missouri',
 (29, 101): u'Johnson County, Missouri',
 (29, 103): u'Knox County, Missouri',
 (29, 105): u'Laclede County, Missouri',
 (29, 107): u'Lafayette County, Missouri',
 (29, 109): u'Lawrence County, Missouri',
 (29, 111): u'Lewis County, Missouri',
 (29, 113): u'Lincoln County, Missouri',
 (29, 115): u'Linn County, Missouri',
 (29, 117): u'Livingston County, Missouri',
 (29, 119): u'McDonald County, Missouri',
 (29, 121): u'Macon County, Missouri',
 (29, 123): u'Madison County, Missouri',
 (29, 125): u'Maries County, Missouri',
 (29, 127): u'Marion County, Missouri',
 (29, 129): u'Mercer County, Missouri',
 (29, 131): u'Miller County, Missouri',
 (29, 133): u'Mississippi County, Missouri',
 (29, 135): u'Moniteau County, Missouri',
 (29, 137): u'Monroe County, Missouri',
 (29, 139): u'Montgomery County, Missouri',
 (29, 141): u'Morgan County, Missouri',
 (29, 143): u'New Madrid County, Missouri',
 (29, 145): u'Newton County, Missouri',
 (29, 147): u'Nodaway County, Missouri',
 (29, 149): u'Oregon County, Missouri',
 (29, 151): u'Osage County, Missouri',
 (29, 153): u'Ozark County, Missouri',
 (29, 155): u'Pemiscot County, Missouri',
 (29, 157): u'Perry County, Missouri',
 (29, 159): u'Pettis County, Missouri',
 (29, 161): u'Phelps County, Missouri',
 (29, 163): u'Pike County, Missouri',
 (29, 165): u'Platte County, Missouri',
 (29, 167): u'Polk County, Missouri',
 (29, 169): u'Pulaski County, Missouri',
 (29, 171): u'Putnam County, Missouri',
 (29, 173): u'Ralls County, Missouri',
 (29, 175): u'Randolph County, Missouri',
 (29, 177): u'Ray County, Missouri',
 (29, 179): u'Reynolds County, Missouri',
 (29, 181): u'Ripley County, Missouri',
 (29, 183): u'St. Charles County, Missouri',
 (29, 185): u'St. Clair County, Missouri',
 (29, 186): u'Ste. Genevieve County, Missouri',
 (29, 187): u'St. Francois County, Missouri',
 (29, 189): u'St. Louis County, Missouri',
 (29, 195): u'Saline County, Missouri',
 (29, 197): u'Schuyler County, Missouri',
 (29, 199): u'Scotland County, Missouri',
 (29, 201): u'Scott County, Missouri',
 (29, 203): u'Shannon County, Missouri',
 (29, 205): u'Shelby County, Missouri',
 (29, 207): u'Stoddard County, Missouri',
 (29, 209): u'Stone County, Missouri',
 (29, 211): u'Sullivan County, Missouri',
 (29, 213): u'Taney County, Missouri',
 (29, 215): u'Texas County, Missouri',
 (29, 217): u'Vernon County, Missouri',
 (29, 219): u'Warren County, Missouri',
 (29, 221): u'Washington County, Missouri',
 (29, 223): u'Wayne County, Missouri',
 (29, 225): u'Webster County, Missouri',
 (29, 227): u'Worth County, Missouri',
 (29, 229): u'Wright County, Missouri',
 (29, 510): u'St. Louis city, Missouri',
 (30, 0): u'Montana',
 (30, 1): u'Beaverhead County, Montana',
 (30, 3): u'Big Horn County, Montana',
 (30, 5): u'Blaine County, Montana',
 (30, 7): u'Broadwater County, Montana',
 (30, 9): u'Carbon County, Montana',
 (30, 11): u'Carter County, Montana',
 (30, 13): u'Cascade County, Montana',
 (30, 15): u'Chouteau County, Montana',
 (30, 17): u'Custer County, Montana',
 (30, 19): u'Daniels County, Montana',
 (30, 21): u'Dawson County, Montana',
 (30, 23): u'Deer Lodge County, Montana',
 (30, 25): u'Fallon County, Montana',
 (30, 27): u'Fergus County, Montana',
 (30, 29): u'Flathead County, Montana',
 (30, 31): u'Gallatin County, Montana',
 (30, 33): u'Garfield County, Montana',
 (30, 35): u'Glacier County, Montana',
 (30, 37): u'Golden Valley County, Montana',
 (30, 39): u'Granite County, Montana',
 (30, 41): u'Hill County, Montana',
 (30, 43): u'Jefferson County, Montana',
 (30, 45): u'Judith Basin County, Montana',
 (30, 47): u'Lake County, Montana',
 (30, 49): u'Lewis and Clark County, Montana',
 (30, 51): u'Liberty County, Montana',
 (30, 53): u'Lincoln County, Montana',
 (30, 55): u'McCone County, Montana',
 (30, 57): u'Madison County, Montana',
 (30, 59): u'Meagher County, Montana',
 (30, 61): u'Mineral County, Montana',
 (30, 63): u'Missoula County, Montana',
 (30, 65): u'Musselshell County, Montana',
 (30, 67): u'Park County, Montana',
 (30, 69): u'Petroleum County, Montana',
 (30, 71): u'Phillips County, Montana',
 (30, 73): u'Pondera County, Montana',
 (30, 75): u'Powder River County, Montana',
 (30, 77): u'Powell County, Montana',
 (30, 79): u'Prairie County, Montana',
 (30, 81): u'Ravalli County, Montana',
 (30, 83): u'Richland County, Montana',
 (30, 85): u'Roosevelt County, Montana',
 (30, 87): u'Rosebud County, Montana',
 (30, 89): u'Sanders County, Montana',
 (30, 91): u'Sheridan County, Montana',
 (30, 93): u'Silver Bow County, Montana',
 (30, 95): u'Stillwater County, Montana',
 (30, 97): u'Sweet Grass County, Montana',
 (30, 99): u'Teton County, Montana',
 (30, 101): u'Toole County, Montana',
 (30, 103): u'Treasure County, Montana',
 (30, 105): u'Valley County, Montana',
 (30, 107): u'Wheatland County, Montana',
 (30, 109): u'Wibaux County, Montana',
 (30, 111): u'Yellowstone County, Montana',
 (31, 0): u'Nebraska',
 (31, 1): u'Adams County, Nebraska',
 (31, 3): u'Antelope County, Nebraska',
 (31, 5): u'Arthur County, Nebraska',
 (31, 7): u'Banner County, Nebraska',
 (31, 9): u'Blaine County, Nebraska',
 (31, 11): u'Boone County, Nebraska',
 (31, 13): u'Box Butte County, Nebraska',
 (31, 15): u'Boyd County, Nebraska',
 (31, 17): u'Brown County, Nebraska',
 (31, 19): u'Buffalo County, Nebraska',
 (31, 21): u'Burt County, Nebraska',
 (31, 23): u'Butler County, Nebraska',
 (31, 25): u'Cass County, Nebraska',
 (31, 27): u'Cedar County, Nebraska',
 (31, 29): u'Chase County, Nebraska',
 (31, 31): u'Cherry County, Nebraska',
 (31, 33): u'Cheyenne County, Nebraska',
 (31, 35): u'Clay County, Nebraska',
 (31, 37): u'Colfax County, Nebraska',
 (31, 39): u'Cuming County, Nebraska',
 (31, 41): u'Custer County, Nebraska',
 (31, 43): u'Dakota County, Nebraska',
 (31, 45): u'Dawes County, Nebraska',
 (31, 47): u'Dawson County, Nebraska',
 (31, 49): u'Deuel County, Nebraska',
 (31, 51): u'Dixon County, Nebraska',
 (31, 53): u'Dodge County, Nebraska',
 (31, 55): u'Douglas County, Nebraska',
 (31, 57): u'Dundy County, Nebraska',
 (31, 59): u'Fillmore County, Nebraska',
 (31, 61): u'Franklin County, Nebraska',
 (31, 63): u'Frontier County, Nebraska',
 (31, 65): u'Furnas County, Nebraska',
 (31, 67): u'Gage County, Nebraska',
 (31, 69): u'Garden County, Nebraska',
 (31, 71): u'Garfield County, Nebraska',
 (31, 73): u'Gosper County, Nebraska',
 (31, 75): u'Grant County, Nebraska',
 (31, 77): u'Greeley County, Nebraska',
 (31, 79): u'Hall County, Nebraska',
 (31, 81): u'Hamilton County, Nebraska',
 (31, 83): u'Harlan County, Nebraska',
 (31, 85): u'Hayes County, Nebraska',
 (31, 87): u'Hitchcock County, Nebraska',
 (31, 89): u'Holt County, Nebraska',
 (31, 91): u'Hooker County, Nebraska',
 (31, 93): u'Howard County, Nebraska',
 (31, 95): u'Jefferson County, Nebraska',
 (31, 97): u'Johnson County, Nebraska',
 (31, 99): u'Kearney County, Nebraska',
 (31, 101): u'Keith County, Nebraska',
 (31, 103): u'Keya Paha County, Nebraska',
 (31, 105): u'Kimball County, Nebraska',
 (31, 107): u'Knox County, Nebraska',
 (31, 109): u'Lancaster County, Nebraska',
 (31, 111): u'Lincoln County, Nebraska',
 (31, 113): u'Logan County, Nebraska',
 (31, 115): u'Loup County, Nebraska',
 (31, 117): u'McPherson County, Nebraska',
 (31, 119): u'Madison County, Nebraska',
 (31, 121): u'Merrick County, Nebraska',
 (31, 123): u'Morrill County, Nebraska',
 (31, 125): u'Nance County, Nebraska',
 (31, 127): u'Nemaha County, Nebraska',
 (31, 129): u'Nuckolls County, Nebraska',
 (31, 131): u'Otoe County, Nebraska',
 (31, 133): u'Pawnee County, Nebraska',
 (31, 135): u'Perkins County, Nebraska',
 (31, 137): u'Phelps County, Nebraska',
 (31, 139): u'Pierce County, Nebraska',
 (31, 141): u'Platte County, Nebraska',
 (31, 143): u'Polk County, Nebraska',
 (31, 145): u'Red Willow County, Nebraska',
 (31, 147): u'Richardson County, Nebraska',
 (31, 149): u'Rock County, Nebraska',
 (31, 151): u'Saline County, Nebraska',
 (31, 153): u'Sarpy County, Nebraska',
 (31, 155): u'Saunders County, Nebraska',
 (31, 157): u'Scotts Bluff County, Nebraska',
 (31, 159): u'Seward County, Nebraska',
 (31, 161): u'Sheridan County, Nebraska',
 (31, 163): u'Sherman County, Nebraska',
 (31, 165): u'Sioux County, Nebraska',
 (31, 167): u'Stanton County, Nebraska',
 (31, 169): u'Thayer County, Nebraska',
 (31, 171): u'Thomas County, Nebraska',
 (31, 173): u'Thurston County, Nebraska',
 (31, 175): u'Valley County, Nebraska',
 (31, 177): u'Washington County, Nebraska',
 (31, 179): u'Wayne County, Nebraska',
 (31, 181): u'Webster County, Nebraska',
 (31, 183): u'Wheeler County, Nebraska',
 (31, 185): u'York County, Nebraska',
 (32, 0): u'Nevada',
 (32, 1): u'Churchill County, Nevada',
 (32, 3): u'Clark County, Nevada',
 (32, 5): u'Douglas County, Nevada',
 (32, 7): u'Elko County, Nevada',
 (32, 9): u'Esmeralda County, Nevada',
 (32, 11): u'Eureka County, Nevada',
 (32, 13): u'Humboldt County, Nevada',
 (32, 15): u'Lander County, Nevada',
 (32, 17): u'Lincoln County, Nevada',
 (32, 19): u'Lyon County, Nevada',
 (32, 21): u'Mineral County, Nevada',
 (32, 23): u'Nye County, Nevada',
 (32, 27): u'Pershing County, Nevada',
 (32, 29): u'Storey County, Nevada',
 (32, 31): u'Washoe County, Nevada',
 (32, 33): u'White Pine County, Nevada',
 (32, 510): u'Carson City, Nevada',
 (33, 0): u'New Hampshire',
 (33, 1): u'Belknap County, New Hampshire',
 (33, 3): u'Carroll County, New Hampshire',
 (33, 5): u'Cheshire County, New Hampshire',
 (33, 7): u'Coos County, New Hampshire',
 (33, 9): u'Grafton County, New Hampshire',
 (33, 11): u'Hillsborough County, New Hampshire',
 (33, 13): u'Merrimack County, New Hampshire',
 (33, 15): u'Rockingham County, New Hampshire',
 (33, 17): u'Strafford County, New Hampshire',
 (33, 19): u'Sullivan County, New Hampshire',
 (34, 0): u'New Jersey',
 (34, 1): u'Atlantic County, New Jersey',
 (34, 3): u'Bergen County, New Jersey',
 (34, 5): u'Burlington County, New Jersey',
 (34, 7): u'Camden County, New Jersey',
 (34, 9): u'Cape May County, New Jersey',
 (34, 11): u'Cumberland County, New Jersey',
 (34, 13): u'Essex County, New Jersey',
 (34, 15): u'Gloucester County, New Jersey',
 (34, 17): u'Hudson County, New Jersey',
 (34, 19): u'Hunterdon County, New Jersey',
 (34, 21): u'Mercer County, New Jersey',
 (34, 23): u'Middlesex County, New Jersey',
 (34, 25): u'Monmouth County, New Jersey',
 (34, 27): u'Morris County, New Jersey',
 (34, 29): u'Ocean County, New Jersey',
 (34, 31): u'Passaic County, New Jersey',
 (34, 33): u'Salem County, New Jersey',
 (34, 35): u'Somerset County, New Jersey',
 (34, 37): u'Sussex County, New Jersey',
 (34, 39): u'Union County, New Jersey',
 (34, 41): u'Warren County, New Jersey',
 (35, 0): u'New Mexico',
 (35, 1): u'Bernalillo County, New Mexico',
 (35, 3): u'Catron County, New Mexico',
 (35, 5): u'Chaves County, New Mexico',
 (35, 6): u'Cibola County, New Mexico',
 (35, 7): u'Colfax County, New Mexico',
 (35, 9): u'Curry County, New Mexico',
 (35, 11): u'De Baca County, New Mexico',
 (35, 13): u'Do\xf1a Ana County, New Mexico',
 (35, 15): u'Eddy County, New Mexico',
 (35, 17): u'Grant County, New Mexico',
 (35, 19): u'Guadalupe County, New Mexico',
 (35, 21): u'Harding County, New Mexico',
 (35, 23): u'Hidalgo County, New Mexico',
 (35, 25): u'Lea County, New Mexico',
 (35, 27): u'Lincoln County, New Mexico',
 (35, 28): u'Los Alamos County, New Mexico',
 (35, 29): u'Luna County, New Mexico',
 (35, 31): u'McKinley County, New Mexico',
 (35, 33): u'Mora County, New Mexico',
 (35, 35): u'Otero County, New Mexico',
 (35, 37): u'Quay County, New Mexico',
 (35, 39): u'Rio Arriba County, New Mexico',
 (35, 41): u'Roosevelt County, New Mexico',
 (35, 43): u'Sandoval County, New Mexico',
 (35, 45): u'San Juan County, New Mexico',
 (35, 47): u'San Miguel County, New Mexico',
 (35, 49): u'Santa Fe County, New Mexico',
 (35, 51): u'Sierra County, New Mexico',
 (35, 53): u'Socorro County, New Mexico',
 (35, 55): u'Taos County, New Mexico',
 (35, 57): u'Torrance County, New Mexico',
 (35, 59): u'Union County, New Mexico',
 (35, 61): u'Valencia County, New Mexico',
 (36, 0): u'New York',
 (36, 1): u'Albany County, New York',
 (36, 3): u'Allegany County, New York',
 (36, 5): u'Bronx County, New York',
 (36, 7): u'Broome County, New York',
 (36, 9): u'Cattaraugus County, New York',
 (36, 11): u'Cayuga County, New York',
 (36, 13): u'Chautauqua County, New York',
 (36, 15): u'Chemung County, New York',
 (36, 17): u'Chenango County, New York',
 (36, 19): u'Clinton County, New York',
 (36, 21): u'Columbia County, New York',
 (36, 23): u'Cortland County, New York',
 (36, 25): u'Delaware County, New York',
 (36, 27): u'Dutchess County, New York',
 (36, 29): u'Erie County, New York',
 (36, 31): u'Essex County, New York',
 (36, 33): u'Franklin County, New York',
 (36, 35): u'Fulton County, New York',
 (36, 37): u'Genesee County, New York',
 (36, 39): u'Greene County, New York',
 (36, 41): u'Hamilton County, New York',
 (36, 43): u'Herkimer County, New York',
 (36, 45): u'Jefferson County, New York',
 (36, 47): u'Kings County, New York',
 (36, 49): u'Lewis County, New York',
 (36, 51): u'Livingston County, New York',
 (36, 53): u'Madison County, New York',
 (36, 55): u'Monroe County, New York',
 (36, 57): u'Montgomery County, New York',
 (36, 59): u'Nassau County, New York',
 (36, 61): u'New York County, New York',
 (36, 63): u'Niagara County, New York',
 (36, 65): u'Oneida County, New York',
 (36, 67): u'Onondaga County, New York',
 (36, 69): u'Ontario County, New York',
 (36, 71): u'Orange County, New York',
 (36, 73): u'Orleans County, New York',
 (36, 75): u'Oswego County, New York',
 (36, 77): u'Otsego County, New York',
 (36, 79): u'Putnam County, New York',
 (36, 81): u'Queens County, New York',
 (36, 83): u'Rensselaer County, New York',
 (36, 85): u'Richmond County, New York',
 (36, 87): u'Rockland County, New York',
 (36, 89): u'St. Lawrence County, New York',
 (36, 91): u'Saratoga County, New York',
 (36, 93): u'Schenectady County, New York',
 (36, 95): u'Schoharie County, New York',
 (36, 97): u'Schuyler County, New York',
 (36, 99): u'Seneca County, New York',
 (36, 101): u'Steuben County, New York',
 (36, 103): u'Suffolk County, New York',
 (36, 105): u'Sullivan County, New York',
 (36, 107): u'Tioga County, New York',
 (36, 109): u'Tompkins County, New York',
 (36, 111): u'Ulster County, New York',
 (36, 113): u'Warren County, New York',
 (36, 115): u'Washington County, New York',
 (36, 117): u'Wayne County, New York',
 (36, 119): u'Westchester County, New York',
 (36, 121): u'Wyoming County, New York',
 (36, 123): u'Yates County, New York',
 (37, 0): u'North Carolina',
 (37, 1): u'Alamance County, North Carolina',
 (37, 3): u'Alexander County, North Carolina',
 (37, 5): u'Alleghany County, North Carolina',
 (37, 7): u'Anson County, North Carolina',
 (37, 9): u'Ashe County, North Carolina',
 (37, 11): u'Avery County, North Carolina',
 (37, 13): u'Beaufort County, North Carolina',
 (37, 15): u'Bertie County, North Carolina',
 (37, 17): u'Bladen County, North Carolina',
 (37, 19): u'Brunswick County, North Carolina',
 (37, 21): u'Buncombe County, North Carolina',
 (37, 23): u'Burke County, North Carolina',
 (37, 25): u'Cabarrus County, North Carolina',
 (37, 27): u'Caldwell County, North Carolina',
 (37, 29): u'Camden County, North Carolina',
 (37, 31): u'Carteret County, North Carolina',
 (37, 33): u'Caswell County, North Carolina',
 (37, 35): u'Catawba County, North Carolina',
 (37, 37): u'Chatham County, North Carolina',
 (37, 39): u'Cherokee County, North Carolina',
 (37, 41): u'Chowan County, North Carolina',
 (37, 43): u'Clay County, North Carolina',
 (37, 45): u'Cleveland County, North Carolina',
 (37, 47): u'Columbus County, North Carolina',
 (37, 49): u'Craven County, North Carolina',
 (37, 51): u'Cumberland County, North Carolina',
 (37, 53): u'Currituck County, North Carolina',
 (37, 55): u'Dare County, North Carolina',
 (37, 57): u'Davidson County, North Carolina',
 (37, 59): u'Davie County, North Carolina',
 (37, 61): u'Duplin County, North Carolina',
 (37, 63): u'Durham County, North Carolina',
 (37, 65): u'Edgecombe County, North Carolina',
 (37, 67): u'Forsyth County, North Carolina',
 (37, 69): u'Franklin County, North Carolina',
 (37, 71): u'Gaston County, North Carolina',
 (37, 73): u'Gates County, North Carolina',
 (37, 75): u'Graham County, North Carolina',
 (37, 77): u'Granville County, North Carolina',
 (37, 79): u'Greene County, North Carolina',
 (37, 81): u'Guilford County, North Carolina',
 (37, 83): u'Halifax County, North Carolina',
 (37, 85): u'Harnett County, North Carolina',
 (37, 87): u'Haywood County, North Carolina',
 (37, 89): u'Henderson County, North Carolina',
 (37, 91): u'Hertford County, North Carolina',
 (37, 93): u'Hoke County, North Carolina',
 (37, 95): u'Hyde County, North Carolina',
 (37, 97): u'Iredell County, North Carolina',
 (37, 99): u'Jackson County, North Carolina',
 (37, 101): u'Johnston County, North Carolina',
 (37, 103): u'Jones County, North Carolina',
 (37, 105): u'Lee County, North Carolina',
 (37, 107): u'Lenoir County, North Carolina',
 (37, 109): u'Lincoln County, North Carolina',
 (37, 111): u'McDowell County, North Carolina',
 (37, 113): u'Macon County, North Carolina',
 (37, 115): u'Madison County, North Carolina',
 (37, 117): u'Martin County, North Carolina',
 (37, 119): u'Mecklenburg County, North Carolina',
 (37, 121): u'Mitchell County, North Carolina',
 (37, 123): u'Montgomery County, North Carolina',
 (37, 125): u'Moore County, North Carolina',
 (37, 127): u'Nash County, North Carolina',
 (37, 129): u'New Hanover County, North Carolina',
 (37, 131): u'Northampton County, North Carolina',
 (37, 133): u'Onslow County, North Carolina',
 (37, 135): u'Orange County, North Carolina',
 (37, 137): u'Pamlico County, North Carolina',
 (37, 139): u'Pasquotank County, North Carolina',
 (37, 141): u'Pender County, North Carolina',
 (37, 143): u'Perquimans County, North Carolina',
 (37, 145): u'Person County, North Carolina',
 (37, 147): u'Pitt County, North Carolina',
 (37, 149): u'Polk County, North Carolina',
 (37, 151): u'Randolph County, North Carolina',
 (37, 153): u'Richmond County, North Carolina',
 (37, 155): u'Robeson County, North Carolina',
 (37, 157): u'Rockingham County, North Carolina',
 (37, 159): u'Rowan County, North Carolina',
 (37, 161): u'Rutherford County, North Carolina',
 (37, 163): u'Sampson County, North Carolina',
 (37, 165): u'Scotland County, North Carolina',
 (37, 167): u'Stanly County, North Carolina',
 (37, 169): u'Stokes County, North Carolina',
 (37, 171): u'Surry County, North Carolina',
 (37, 173): u'Swain County, North Carolina',
 (37, 175): u'Transylvania County, North Carolina',
 (37, 177): u'Tyrrell County, North Carolina',
 (37, 179): u'Union County, North Carolina',
 (37, 181): u'Vance County, North Carolina',
 (37, 183): u'Wake County, North Carolina',
 (37, 185): u'Warren County, North Carolina',
 (37, 187): u'Washington County, North Carolina',
 (37, 189): u'Watauga County, North Carolina',
 (37, 191): u'Wayne County, North Carolina',
 (37, 193): u'Wilkes County, North Carolina',
 (37, 195): u'Wilson County, North Carolina',
 (37, 197): u'Yadkin County, North Carolina',
 (37, 199): u'Yancey County, North Carolina',
 (38, 0): u'North Dakota',
 (38, 1): u'Adams County, North Dakota',
 (38, 3): u'Barnes County, North Dakota',
 (38, 5): u'Benson County, North Dakota',
 (38, 7): u'Billings County, North Dakota',
 (38, 9): u'Bottineau County, North Dakota',
 (38, 11): u'Bowman County, North Dakota',
 (38, 13): u'Burke County, North Dakota',
 (38, 15): u'Burleigh County, North Dakota',
 (38, 17): u'Cass County, North Dakota',
 (38, 19): u'Cavalier County, North Dakota',
 (38, 21): u'Dickey County, North Dakota',
 (38, 23): u'Divide County, North Dakota',
 (38, 25): u'Dunn County, North Dakota',
 (38, 27): u'Eddy County, North Dakota',
 (38, 29): u'Emmons County, North Dakota',
 (38, 31): u'Foster County, North Dakota',
 (38, 33): u'Golden Valley County, North Dakota',
 (38, 35): u'Grand Forks County, North Dakota',
 (38, 37): u'Grant County, North Dakota',
 (38, 39): u'Griggs County, North Dakota',
 (38, 41): u'Hettinger County, North Dakota',
 (38, 43): u'Kidder County, North Dakota',
 (38, 45): u'LaMoure County, North Dakota',
 (38, 47): u'Logan County, North Dakota',
 (38, 49): u'McHenry County, North Dakota',
 (38, 51): u'McIntosh County, North Dakota',
 (38, 53): u'McKenzie County, North Dakota',
 (38, 55): u'McLean County, North Dakota',
 (38, 57): u'Mercer County, North Dakota',
 (38, 59): u'Morton County, North Dakota',
 (38, 61): u'Mountrail County, North Dakota',
 (38, 63): u'Nelson County, North Dakota',
 (38, 65): u'Oliver County, North Dakota',
 (38, 67): u'Pembina County, North Dakota',
 (38, 69): u'Pierce County, North Dakota',
 (38, 71): u'Ramsey County, North Dakota',
 (38, 73): u'Ransom County, North Dakota',
 (38, 75): u'Renville County, North Dakota',
 (38, 77): u'Richland County, North Dakota',
 (38, 79): u'Rolette County, North Dakota',
 (38, 81): u'Sargent County, North Dakota',
 (38, 83): u'Sheridan County, North Dakota',
 (38, 85): u'Sioux County, North Dakota',
 (38, 87): u'Slope County, North Dakota',
 (38, 89): u'Stark County, North Dakota',
 (38, 91): u'Steele County, North Dakota',
 (38, 93): u'Stutsman County, North Dakota',
 (38, 95): u'Towner County, North Dakota',
 (38, 97): u'Traill County, North Dakota',
 (38, 99): u'Walsh County, North Dakota',
 (38, 101): u'Ward County, North Dakota',
 (38, 103): u'Wells County, North Dakota',
 (38, 105): u'Williams County, North Dakota',
 (39, 0): u'Ohio',
 (39, 1): u'Adams County, Ohio',
 (39, 3): u'Allen County, Ohio',
 (39, 5): u'Ashland County, Ohio',
 (39, 7): u'Ashtabula County, Ohio',
 (39, 9): u'Athens County, Ohio',
 (39, 11): u'Auglaize County, Ohio',
 (39, 13): u'Belmont County, Ohio',
 (39, 15): u'Brown County, Ohio',
 (39, 17): u'Butler County, Ohio',
 (39, 19): u'Carroll County, Ohio',
 (39, 21): u'Champaign County, Ohio',
 (39, 23): u'Clark County, Ohio',
 (39, 25): u'Clermont County, Ohio',
 (39, 27): u'Clinton County, Ohio',
 (39, 29): u'Columbiana County, Ohio',
 (39, 31): u'Coshocton County, Ohio',
 (39, 33): u'Crawford County, Ohio',
 (39, 35): u'Cuyahoga County, Ohio',
 (39, 37): u'Darke County, Ohio',
 (39, 39): u'Defiance County, Ohio',
 (39, 41): u'Delaware County, Ohio',
 (39, 43): u'Erie County, Ohio',
 (39, 45): u'Fairfield County, Ohio',
 (39, 47): u'Fayette County, Ohio',
 (39, 49): u'Franklin County, Ohio',
 (39, 51): u'Fulton County, Ohio',
 (39, 53): u'Gallia County, Ohio',
 (39, 55): u'Geauga County, Ohio',
 (39, 57): u'Greene County, Ohio',
 (39, 59): u'Guernsey County, Ohio',
 (39, 61): u'Hamilton County, Ohio',
 (39, 63): u'Hancock County, Ohio',
 (39, 65): u'Hardin County, Ohio',
 (39, 67): u'Harrison County, Ohio',
 (39, 69): u'Henry County, Ohio',
 (39, 71): u'Highland County, Ohio',
 (39, 73): u'Hocking County, Ohio',
 (39, 75): u'Holmes County, Ohio',
 (39, 77): u'Huron County, Ohio',
 (39, 79): u'Jackson County, Ohio',
 (39, 81): u'Jefferson County, Ohio',
 (39, 83): u'Knox County, Ohio',
 (39, 85): u'Lake County, Ohio',
 (39, 87): u'Lawrence County, Ohio',
 (39, 89): u'Licking County, Ohio',
 (39, 91): u'Logan County, Ohio',
 (39, 93): u'Lorain County, Ohio',
 (39, 95): u'Lucas County, Ohio',
 (39, 97): u'Madison County, Ohio',
 (39, 99): u'Mahoning County, Ohio',
 (39, 101): u'Marion County, Ohio',
 (39, 103): u'Medina County, Ohio',
 (39, 105): u'Meigs County, Ohio',
 (39, 107): u'Mercer County, Ohio',
 (39, 109): u'Miami County, Ohio',
 (39, 111): u'Monroe County, Ohio',
 (39, 113): u'Montgomery County, Ohio',
 (39, 115): u'Morgan County, Ohio',
 (39, 117): u'Morrow County, Ohio',
 (39, 119): u'Muskingum County, Ohio',
 (39, 121): u'Noble County, Ohio',
 (39, 123): u'Ottawa County, Ohio',
 (39, 125): u'Paulding County, Ohio',
 (39, 127): u'Perry County, Ohio',
 (39, 129): u'Pickaway County, Ohio',
 (39, 131): u'Pike County, Ohio',
 (39, 133): u'Portage County, Ohio',
 (39, 135): u'Preble County, Ohio',
 (39, 137): u'Putnam County, Ohio',
 (39, 139): u'Richland County, Ohio',
 (39, 141): u'Ross County, Ohio',
 (39, 143): u'Sandusky County, Ohio',
 (39, 145): u'Scioto County, Ohio',
 (39, 147): u'Seneca County, Ohio',
 (39, 149): u'Shelby County, Ohio',
 (39, 151): u'Stark County, Ohio',
 (39, 153): u'Summit County, Ohio',
 (39, 155): u'Trumbull County, Ohio',
 (39, 157): u'Tuscarawas County, Ohio',
 (39, 159): u'Union County, Ohio',
 (39, 161): u'Van Wert County, Ohio',
 (39, 163): u'Vinton County, Ohio',
 (39, 165): u'Warren County, Ohio',
 (39, 167): u'Washington County, Ohio',
 (39, 169): u'Wayne County, Ohio',
 (39, 171): u'Williams County, Ohio',
 (39, 173): u'Wood County, Ohio',
 (39, 175): u'Wyandot County, Ohio',
 (40, 0): u'Oklahoma',
 (40, 1): u'Adair County, Oklahoma',
 (40, 3): u'Alfalfa County, Oklahoma',
 (40, 5): u'Atoka County, Oklahoma',
 (40, 7): u'Beaver County, Oklahoma',
 (40, 9): u'Beckham County, Oklahoma',
 (40, 11): u'Blaine County, Oklahoma',
 (40, 13): u'Bryan County, Oklahoma',
 (40, 15): u'Caddo County, Oklahoma',
 (40, 17): u'Canadian County, Oklahoma',
 (40, 19): u'Carter County, Oklahoma',
 (40, 21): u'Cherokee County, Oklahoma',
 (40, 23): u'Choctaw County, Oklahoma',
 (40, 25): u'Cimarron County, Oklahoma',
 (40, 27): u'Cleveland County, Oklahoma',
 (40, 29): u'Coal County, Oklahoma',
 (40, 31): u'Comanche County, Oklahoma',
 (40, 33): u'Cotton County, Oklahoma',
 (40, 35): u'Craig County, Oklahoma',
 (40, 37): u'Creek County, Oklahoma',
 (40, 39): u'Custer County, Oklahoma',
 (40, 41): u'Delaware County, Oklahoma',
 (40, 43): u'Dewey County, Oklahoma',
 (40, 45): u'Ellis County, Oklahoma',
 (40, 47): u'Garfield County, Oklahoma',
 (40, 49): u'Garvin County, Oklahoma',
 (40, 51): u'Grady County, Oklahoma',
 (40, 53): u'Grant County, Oklahoma',
 (40, 55): u'Greer County, Oklahoma',
 (40, 57): u'Harmon County, Oklahoma',
 (40, 59): u'Harper County, Oklahoma',
 (40, 61): u'Haskell County, Oklahoma',
 (40, 63): u'Hughes County, Oklahoma',
 (40, 65): u'Jackson County, Oklahoma',
 (40, 67): u'Jefferson County, Oklahoma',
 (40, 69): u'Johnston County, Oklahoma',
 (40, 71): u'Kay County, Oklahoma',
 (40, 73): u'Kingfisher County, Oklahoma',
 (40, 75): u'Kiowa County, Oklahoma',
 (40, 77): u'Latimer County, Oklahoma',
 (40, 79): u'Le Flore County, Oklahoma',
 (40, 81): u'Lincoln County, Oklahoma',
 (40, 83): u'Logan County, Oklahoma',
 (40, 85): u'Love County, Oklahoma',
 (40, 87): u'McClain County, Oklahoma',
 (40, 89): u'McCurtain County, Oklahoma',
 (40, 91): u'McIntosh County, Oklahoma',
 (40, 93): u'Major County, Oklahoma',
 (40, 95): u'Marshall County, Oklahoma',
 (40, 97): u'Mayes County, Oklahoma',
 (40, 99): u'Murray County, Oklahoma',
 (40, 101): u'Muskogee County, Oklahoma',
 (40, 103): u'Noble County, Oklahoma',
 (40, 105): u'Nowata County, Oklahoma',
 (40, 107): u'Okfuskee County, Oklahoma',
 (40, 109): u'Oklahoma County, Oklahoma',
 (40, 111): u'Okmulgee County, Oklahoma',
 (40, 113): u'Osage County, Oklahoma',
 (40, 115): u'Ottawa County, Oklahoma',
 (40, 117): u'Pawnee County, Oklahoma',
 (40, 119): u'Payne County, Oklahoma',
 (40, 121): u'Pittsburg County, Oklahoma',
 (40, 123): u'Pontotoc County, Oklahoma',
 (40, 125): u'Pottawatomie County, Oklahoma',
 (40, 127): u'Pushmataha County, Oklahoma',
 (40, 129): u'Roger Mills County, Oklahoma',
 (40, 131): u'Rogers County, Oklahoma',
 (40, 133): u'Seminole County, Oklahoma',
 (40, 135): u'Sequoyah County, Oklahoma',
 (40, 137): u'Stephens County, Oklahoma',
 (40, 139): u'Texas County, Oklahoma',
 (40, 141): u'Tillman County, Oklahoma',
 (40, 143): u'Tulsa County, Oklahoma',
 (40, 145): u'Wagoner County, Oklahoma',
 (40, 147): u'Washington County, Oklahoma',
 (40, 149): u'Washita County, Oklahoma',
 (40, 151): u'Woods County, Oklahoma',
 (40, 153): u'Woodward County, Oklahoma',
 (41, 0): u'Oregon',
 (41, 1): u'Baker County, Oregon',
 (41, 3): u'Benton County, Oregon',
 (41, 5): u'Clackamas County, Oregon',
 (41, 7): u'Clatsop County, Oregon',
 (41, 9): u'Columbia County, Oregon',
 (41, 11): u'Coos County, Oregon',
 (41, 13): u'Crook County, Oregon',
 (41, 15): u'Curry County, Oregon',
 (41, 17): u'Deschutes County, Oregon',
 (41, 19): u'Douglas County, Oregon',
 (41, 21): u'Gilliam County, Oregon',
 (41, 23): u'Grant County, Oregon',
 (41, 25): u'Harney County, Oregon',
 (41, 27): u'Hood River County, Oregon',
 (41, 29): u'Jackson County, Oregon',
 (41, 31): u'Jefferson County, Oregon',
 (41, 33): u'Josephine County, Oregon',
 (41, 35): u'Klamath County, Oregon',
 (41, 37): u'Lake County, Oregon',
 (41, 39): u'Lane County, Oregon',
 (41, 41): u'Lincoln County, Oregon',
 (41, 43): u'Linn County, Oregon',
 (41, 45): u'Malheur County, Oregon',
 (41, 47): u'Marion County, Oregon',
 (41, 49): u'Morrow County, Oregon',
 (41, 51): u'Multnomah County, Oregon',
 (41, 53): u'Polk County, Oregon',
 (41, 55): u'Sherman County, Oregon',
 (41, 57): u'Tillamook County, Oregon',
 (41, 59): u'Umatilla County, Oregon',
 (41, 61): u'Union County, Oregon',
 (41, 63): u'Wallowa County, Oregon',
 (41, 65): u'Wasco County, Oregon',
 (41, 67): u'Washington County, Oregon',
 (41, 69): u'Wheeler County, Oregon',
 (41, 71): u'Yamhill County, Oregon',
 (42, 0): u'Pennsylvania',
 (42, 1): u'Adams County, Pennsylvania',
 (42, 3): u'Allegheny County, Pennsylvania',
 (42, 5): u'Armstrong County, Pennsylvania',
 (42, 7): u'Beaver County, Pennsylvania',
 (42, 9): u'Bedford County, Pennsylvania',
 (42, 11): u'Berks County, Pennsylvania',
 (42, 13): u'Blair County, Pennsylvania',
 (42, 15): u'Bradford County, Pennsylvania',
 (42, 17): u'Bucks County, Pennsylvania',
 (42, 19): u'Butler County, Pennsylvania',
 (42, 21): u'Cambria County, Pennsylvania',
 (42, 23): u'Cameron County, Pennsylvania',
 (42, 25): u'Carbon County, Pennsylvania',
 (42, 27): u'Centre County, Pennsylvania',
 (42, 29): u'Chester County, Pennsylvania',
 (42, 31): u'Clarion County, Pennsylvania',
 (42, 33): u'Clearfield County, Pennsylvania',
 (42, 35): u'Clinton County, Pennsylvania',
 (42, 37): u'Columbia County, Pennsylvania',
 (42, 39): u'Crawford County, Pennsylvania',
 (42, 41): u'Cumberland County, Pennsylvania',
 (42, 43): u'Dauphin County, Pennsylvania',
 (42, 45): u'Delaware County, Pennsylvania',
 (42, 47): u'Elk County, Pennsylvania',
 (42, 49): u'Erie County, Pennsylvania',
 (42, 51): u'Fayette County, Pennsylvania',
 (42, 53): u'Forest County, Pennsylvania',
 (42, 55): u'Franklin County, Pennsylvania',
 (42, 57): u'Fulton County, Pennsylvania',
 (42, 59): u'Greene County, Pennsylvania',
 (42, 61): u'Huntingdon County, Pennsylvania',
 (42, 63): u'Indiana County, Pennsylvania',
 (42, 65): u'Jefferson County, Pennsylvania',
 (42, 67): u'Juniata County, Pennsylvania',
 (42, 69): u'Lackawanna County, Pennsylvania',
 (42, 71): u'Lancaster County, Pennsylvania',
 (42, 73): u'Lawrence County, Pennsylvania',
 (42, 75): u'Lebanon County, Pennsylvania',
 (42, 77): u'Lehigh County, Pennsylvania',
 (42, 79): u'Luzerne County, Pennsylvania',
 (42, 81): u'Lycoming County, Pennsylvania',
 (42, 83): u'McKean County, Pennsylvania',
 (42, 85): u'Mercer County, Pennsylvania',
 (42, 87): u'Mifflin County, Pennsylvania',
 (42, 89): u'Monroe County, Pennsylvania',
 (42, 91): u'Montgomery County, Pennsylvania',
 (42, 93): u'Montour County, Pennsylvania',
 (42, 95): u'Northampton County, Pennsylvania',
 (42, 97): u'Northumberland County, Pennsylvania',
 (42, 99): u'Perry County, Pennsylvania',
 (42, 101): u'Philadelphia County, Pennsylvania',
 (42, 103): u'Pike County, Pennsylvania',
 (42, 105): u'Potter County, Pennsylvania',
 (42, 107): u'Schuylkill County, Pennsylvania',
 (42, 109): u'Snyder County, Pennsylvania',
 (42, 111): u'Somerset County, Pennsylvania',
 (42, 113): u'Sullivan County, Pennsylvania',
 (42, 115): u'Susquehanna County, Pennsylvania',
 (42, 117): u'Tioga County, Pennsylvania',
 (42, 119): u'Union County, Pennsylvania',
 (42, 121): u'Venango County, Pennsylvania',
 (42, 123): u'Warren County, Pennsylvania',
 (42, 125): u'Washington County, Pennsylvania',
 (42, 127): u'Wayne County, Pennsylvania',
 (42, 129): u'Westmoreland County, Pennsylvania',
 (42, 131): u'Wyoming County, Pennsylvania',
 (42, 133): u'York County, Pennsylvania',
 (44, 0): u'Rhode Island',
 (44, 1): u'Bristol County, Rhode Island',
 (44, 3): u'Kent County, Rhode Island',
 (44, 5): u'Newport County, Rhode Island',
 (44, 7): u'Providence County, Rhode Island',
 (44, 9): u'Washington County, Rhode Island',
 (45, 0): u'South Carolina',
 (45, 1): u'Abbeville County, South Carolina',
 (45, 3): u'Aiken County, South Carolina',
 (45, 5): u'Allendale County, South Carolina',
 (45, 7): u'Anderson County, South Carolina',
 (45, 9): u'Bamberg County, South Carolina',
 (45, 11): u'Barnwell County, South Carolina',
 (45, 13): u'Beaufort County, South Carolina',
 (45, 15): u'Berkeley County, South Carolina',
 (45, 17): u'Calhoun County, South Carolina',
 (45, 19): u'Charleston County, South Carolina',
 (45, 21): u'Cherokee County, South Carolina',
 (45, 23): u'Chester County, South Carolina',
 (45, 25): u'Chesterfield County, South Carolina',
 (45, 27): u'Clarendon County, South Carolina',
 (45, 29): u'Colleton County, South Carolina',
 (45, 31): u'Darlington County, South Carolina',
 (45, 33): u'Dillon County, South Carolina',
 (45, 35): u'Dorchester County, South Carolina',
 (45, 37): u'Edgefield County, South Carolina',
 (45, 39): u'Fairfield County, South Carolina',
 (45, 41): u'Florence County, South Carolina',
 (45, 43): u'Georgetown County, South Carolina',
 (45, 45): u'Greenville County, South Carolina',
 (45, 47): u'Greenwood County, South Carolina',
 (45, 49): u'Hampton County, South Carolina',
 (45, 51): u'Horry County, South Carolina',
 (45, 53): u'Jasper County, South Carolina',
 (45, 55): u'Kershaw County, South Carolina',
 (45, 57): u'Lancaster County, South Carolina',
 (45, 59): u'Laurens County, South Carolina',
 (45, 61): u'Lee County, South Carolina',
 (45, 63): u'Lexington County, South Carolina',
 (45, 65): u'McCormick County, South Carolina',
 (45, 67): u'Marion County, South Carolina',
 (45, 69): u'Marlboro County, South Carolina',
 (45, 71): u'Newberry County, South Carolina',
 (45, 73): u'Oconee County, South Carolina',
 (45, 75): u'Orangeburg County, South Carolina',
 (45, 77): u'Pickens County, South Carolina',
 (45, 79): u'Richland County, South Carolina',
 (45, 81): u'Saluda County, South Carolina',
 (45, 83): u'Spartanburg County, South Carolina',
 (45, 85): u'Sumter County, South Carolina',
 (45, 87): u'Union County, South Carolina',
 (45, 89): u'Williamsburg County, South Carolina',
 (45, 91): u'York County, South Carolina',
 (46, 0): u'South Dakota',
 (46, 3): u'Aurora County, South Dakota',
 (46, 5): u'Beadle County, South Dakota',
 (46, 7): u'Bennett County, South Dakota',
 (46, 9): u'Bon Homme County, South Dakota',
 (46, 11): u'Brookings County, South Dakota',
 (46, 13): u'Brown County, South Dakota',
 (46, 15): u'Brule County, South Dakota',
 (46, 17): u'Buffalo County, South Dakota',
 (46, 19): u'Butte County, South Dakota',
 (46, 21): u'Campbell County, South Dakota',
 (46, 23): u'Charles Mix County, South Dakota',
 (46, 25): u'Clark County, South Dakota',
 (46, 27): u'Clay County, South Dakota',
 (46, 29): u'Codington County, South Dakota',
 (46, 31): u'Corson County, South Dakota',
 (46, 33): u'Custer County, South Dakota',
 (46, 35): u'Davison County, South Dakota',
 (46, 37): u'Day County, South Dakota',
 (46, 39): u'Deuel County, South Dakota',
 (46, 41): u'Dewey County, South Dakota',
 (46, 43): u'Douglas County, South Dakota',
 (46, 45): u'Edmunds County, South Dakota',
 (46, 47): u'Fall River County, South Dakota',
 (46, 49): u'Faulk County, South Dakota',
 (46, 51): u'Grant County, South Dakota',
 (46, 53): u'Gregory County, South Dakota',
 (46, 55): u'Haakon County, South Dakota',
 (46, 57): u'Hamlin County, South Dakota',
 (46, 59): u'Hand County, South Dakota',
 (46, 61): u'Hanson County, South Dakota',
 (46, 63): u'Harding County, South Dakota',
 (46, 65): u'Hughes County, South Dakota',
 (46, 67): u'Hutchinson County, South Dakota',
 (46, 69): u'Hyde County, South Dakota',
 (46, 71): u'Jackson County, South Dakota',
 (46, 73): u'Jerauld County, South Dakota',
 (46, 75): u'Jones County, South Dakota',
 (46, 77): u'Kingsbury County, South Dakota',
 (46, 79): u'Lake County, South Dakota',
 (46, 81): u'Lawrence County, South Dakota',
 (46, 83): u'Lincoln County, South Dakota',
 (46, 85): u'Lyman County, South Dakota',
 (46, 87): u'McCook County, South Dakota',
 (46, 89): u'McPherson County, South Dakota',
 (46, 91): u'Marshall County, South Dakota',
 (46, 93): u'Meade County, South Dakota',
 (46, 95): u'Mellette County, South Dakota',
 (46, 97): u'Miner County, South Dakota',
 (46, 99): u'Minnehaha County, South Dakota',
 (46, 101): u'Moody County, South Dakota',
 (46, 103): u'Pennington County, South Dakota',
 (46, 105): u'Perkins County, South Dakota',
 (46, 107): u'Potter County, South Dakota',
 (46, 109): u'Roberts County, South Dakota',
 (46, 111): u'Sanborn County, South Dakota',
 (46, 113): u'Shannon County, South Dakota',
 (46, 115): u'Spink County, South Dakota',
 (46, 117): u'Stanley County, South Dakota',
 (46, 119): u'Sully County, South Dakota',
 (46, 121): u'Todd County, South Dakota',
 (46, 123): u'Tripp County, South Dakota',
 (46, 125): u'Turner County, South Dakota',
 (46, 127): u'Union County, South Dakota',
 (46, 129): u'Walworth County, South Dakota',
 (46, 135): u'Yankton County, South Dakota',
 (46, 137): u'Ziebach County, South Dakota',
 (47, 0): u'Tennessee',
 (47, 1): u'Anderson County, Tennessee',
 (47, 3): u'Bedford County, Tennessee',
 (47, 5): u'Benton County, Tennessee',
 (47, 7): u'Bledsoe County, Tennessee',
 (47, 9): u'Blount County, Tennessee',
 (47, 11): u'Bradley County, Tennessee',
 (47, 13): u'Campbell County, Tennessee',
 (47, 15): u'Cannon County, Tennessee',
 (47, 17): u'Carroll County, Tennessee',
 (47, 19): u'Carter County, Tennessee',
 (47, 21): u'Cheatham County, Tennessee',
 (47, 23): u'Chester County, Tennessee',
 (47, 25): u'Claiborne County, Tennessee',
 (47, 27): u'Clay County, Tennessee',
 (47, 29): u'Cocke County, Tennessee',
 (47, 31): u'Coffee County, Tennessee',
 (47, 33): u'Crockett County, Tennessee',
 (47, 35): u'Cumberland County, Tennessee',
 (47, 37): u'Davidson County, Tennessee',
 (47, 39): u'Decatur County, Tennessee',
 (47, 41): u'DeKalb County, Tennessee',
 (47, 43): u'Dickson County, Tennessee',
 (47, 45): u'Dyer County, Tennessee',
 (47, 47): u'Fayette County, Tennessee',
 (47, 49): u'Fentress County, Tennessee',
 (47, 51): u'Franklin County, Tennessee',
 (47, 53): u'Gibson County, Tennessee',
 (47, 55): u'Giles County, Tennessee',
 (47, 57): u'Grainger County, Tennessee',
 (47, 59): u'Greene County, Tennessee',
 (47, 61): u'Grundy County, Tennessee',
 (47, 63): u'Hamblen County, Tennessee',
 (47, 65): u'Hamilton County, Tennessee',
 (47, 67): u'Hancock County, Tennessee',
 (47, 69): u'Hardeman County, Tennessee',
 (47, 71): u'Hardin County, Tennessee',
 (47, 73): u'Hawkins County, Tennessee',
 (47, 75): u'Haywood County, Tennessee',
 (47, 77): u'Henderson County, Tennessee',
 (47, 79): u'Henry County, Tennessee',
 (47, 81): u'Hickman County, Tennessee',
 (47, 83): u'Houston County, Tennessee',
 (47, 85): u'Humphreys County, Tennessee',
 (47, 87): u'Jackson County, Tennessee',
 (47, 89): u'Jefferson County, Tennessee',
 (47, 91): u'Johnson County, Tennessee',
 (47, 93): u'Knox County, Tennessee',
 (47, 95): u'Lake County, Tennessee',
 (47, 97): u'Lauderdale County, Tennessee',
 (47, 99): u'Lawrence County, Tennessee',
 (47, 101): u'Lewis County, Tennessee',
 (47, 103): u'Lincoln County, Tennessee',
 (47, 105): u'Loudon County, Tennessee',
 (47, 107): u'McMinn County, Tennessee',
 (47, 109): u'McNairy County, Tennessee',
 (47, 111): u'Macon County, Tennessee',
 (47, 113): u'Madison County, Tennessee',
 (47, 115): u'Marion County, Tennessee',
 (47, 117): u'Marshall County, Tennessee',
 (47, 119): u'Maury County, Tennessee',
 (47, 121): u'Meigs County, Tennessee',
 (47, 123): u'Monroe County, Tennessee',
 (47, 125): u'Montgomery County, Tennessee',
 (47, 127): u'Moore County, Tennessee',
 (47, 129): u'Morgan County, Tennessee',
 (47, 131): u'Obion County, Tennessee',
 (47, 133): u'Overton County, Tennessee',
 (47, 135): u'Perry County, Tennessee',
 (47, 137): u'Pickett County, Tennessee',
 (47, 139): u'Polk County, Tennessee',
 (47, 141): u'Putnam County, Tennessee',
 (47, 143): u'Rhea County, Tennessee',
 (47, 145): u'Roane County, Tennessee',
 (47, 147): u'Robertson County, Tennessee',
 (47, 149): u'Rutherford County, Tennessee',
 (47, 151): u'Scott County, Tennessee',
 (47, 153): u'Sequatchie County, Tennessee',
 (47, 155): u'Sevier County, Tennessee',
 (47, 157): u'Shelby County, Tennessee',
 (47, 159): u'Smith County, Tennessee',
 (47, 161): u'Stewart County, Tennessee',
 (47, 163): u'Sullivan County, Tennessee',
 (47, 165): u'Sumner County, Tennessee',
 (47, 167): u'Tipton County, Tennessee',
 (47, 169): u'Trousdale County, Tennessee',
 (47, 171): u'Unicoi County, Tennessee',
 (47, 173): u'Union County, Tennessee',
 (47, 175): u'Van Buren County, Tennessee',
 (47, 177): u'Warren County, Tennessee',
 (47, 179): u'Washington County, Tennessee',
 (47, 181): u'Wayne County, Tennessee',
 (47, 183): u'Weakley County, Tennessee',
 (47, 185): u'White County, Tennessee',
 (47, 187): u'Williamson County, Tennessee',
 (47, 189): u'Wilson County, Tennessee',
 (48, 0): u'Texas',
 (48, 1): u'Anderson County, Texas',
 (48, 3): u'Andrews County, Texas',
 (48, 5): u'Angelina County, Texas',
 (48, 7): u'Aransas County, Texas',
 (48, 9): u'Archer County, Texas',
 (48, 11): u'Armstrong County, Texas',
 (48, 13): u'Atascosa County, Texas',
 (48, 15): u'Austin County, Texas',
 (48, 17): u'Bailey County, Texas',
 (48, 19): u'Bandera County, Texas',
 (48, 21): u'Bastrop County, Texas',
 (48, 23): u'Baylor County, Texas',
 (48, 25): u'Bee County, Texas',
 (48, 27): u'Bell County, Texas',
 (48, 29): u'Bexar County, Texas',
 (48, 31): u'Blanco County, Texas',
 (48, 33): u'Borden County, Texas',
 (48, 35): u'Bosque County, Texas',
 (48, 37): u'Bowie County, Texas',
 (48, 39): u'Brazoria County, Texas',
 (48, 41): u'Brazos County, Texas',
 (48, 43): u'Brewster County, Texas',
 (48, 45): u'Briscoe County, Texas',
 (48, 47): u'Brooks County, Texas',
 (48, 49): u'Brown County, Texas',
 (48, 51): u'Burleson County, Texas',
 (48, 53): u'Burnet County, Texas',
 (48, 55): u'Caldwell County, Texas',
 (48, 57): u'Calhoun County, Texas',
 (48, 59): u'Callahan County, Texas',
 (48, 61): u'Cameron County, Texas',
 (48, 63): u'Camp County, Texas',
 (48, 65): u'Carson County, Texas',
 (48, 67): u'Cass County, Texas',
 (48, 69): u'Castro County, Texas',
 (48, 71): u'Chambers County, Texas',
 (48, 73): u'Cherokee County, Texas',
 (48, 75): u'Childress County, Texas',
 (48, 77): u'Clay County, Texas',
 (48, 79): u'Cochran County, Texas',
 (48, 81): u'Coke County, Texas',
 (48, 83): u'Coleman County, Texas',
 (48, 85): u'Collin County, Texas',
 (48, 87): u'Collingsworth County, Texas',
 (48, 89): u'Colorado County, Texas',
 (48, 91): u'Comal County, Texas',
 (48, 93): u'Comanche County, Texas',
 (48, 95): u'Concho County, Texas',
 (48, 97): u'Cooke County, Texas',
 (48, 99): u'Coryell County, Texas',
 (48, 101): u'Cottle County, Texas',
 (48, 103): u'Crane County, Texas',
 (48, 105): u'Crockett County, Texas',
 (48, 107): u'Crosby County, Texas',
 (48, 109): u'Culberson County, Texas',
 (48, 111): u'Dallam County, Texas',
 (48, 113): u'Dallas County, Texas',
 (48, 115): u'Dawson County, Texas',
 (48, 117): u'Deaf Smith County, Texas',
 (48, 119): u'Delta County, Texas',
 (48, 121): u'Denton County, Texas',
 (48, 123): u'DeWitt County, Texas',
 (48, 125): u'Dickens County, Texas',
 (48, 127): u'Dimmit County, Texas',
 (48, 129): u'Donley County, Texas',
 (48, 131): u'Duval County, Texas',
 (48, 133): u'Eastland County, Texas',
 (48, 135): u'Ector County, Texas',
 (48, 137): u'Edwards County, Texas',
 (48, 139): u'Ellis County, Texas',
 (48, 141): u'El Paso County, Texas',
 (48, 143): u'Erath County, Texas',
 (48, 145): u'Falls County, Texas',
 (48, 147): u'Fannin County, Texas',
 (48, 149): u'Fayette County, Texas',
 (48, 151): u'Fisher County, Texas',
 (48, 153): u'Floyd County, Texas',
 (48, 155): u'Foard County, Texas',
 (48, 157): u'Fort Bend County, Texas',
 (48, 159): u'Franklin County, Texas',
 (48, 161): u'Freestone County, Texas',
 (48, 163): u'Frio County, Texas',
 (48, 165): u'Gaines County, Texas',
 (48, 167): u'Galveston County, Texas',
 (48, 169): u'Garza County, Texas',
 (48, 171): u'Gillespie County, Texas',
 (48, 173): u'Glasscock County, Texas',
 (48, 175): u'Goliad County, Texas',
 (48, 177): u'Gonzales County, Texas',
 (48, 179): u'Gray County, Texas',
 (48, 181): u'Grayson County, Texas',
 (48, 183): u'Gregg County, Texas',
 (48, 185): u'Grimes County, Texas',
 (48, 187): u'Guadalupe County, Texas',
 (48, 189): u'Hale County, Texas',
 (48, 191): u'Hall County, Texas',
 (48, 193): u'Hamilton County, Texas',
 (48, 195): u'Hansford County, Texas',
 (48, 197): u'Hardeman County, Texas',
 (48, 199): u'Hardin County, Texas',
 (48, 201): u'Harris County, Texas',
 (48, 203): u'Harrison County, Texas',
 (48, 205): u'Hartley County, Texas',
 (48, 207): u'Haskell County, Texas',
 (48, 209): u'Hays County, Texas',
 (48, 211): u'Hemphill County, Texas',
 (48, 213): u'Henderson County, Texas',
 (48, 215): u'Hidalgo County, Texas',
 (48, 217): u'Hill County, Texas',
 (48, 219): u'Hockley County, Texas',
 (48, 221): u'Hood County, Texas',
 (48, 223): u'Hopkins County, Texas',
 (48, 225): u'Houston County, Texas',
 (48, 227): u'Howard County, Texas',
 (48, 229): u'Hudspeth County, Texas',
 (48, 231): u'Hunt County, Texas',
 (48, 233): u'Hutchinson County, Texas',
 (48, 235): u'Irion County, Texas',
 (48, 237): u'Jack County, Texas',
 (48, 239): u'Jackson County, Texas',
 (48, 241): u'Jasper County, Texas',
 (48, 243): u'Jeff Davis County, Texas',
 (48, 245): u'Jefferson County, Texas',
 (48, 247): u'Jim Hogg County, Texas',
 (48, 249): u'Jim Wells County, Texas',
 (48, 251): u'Johnson County, Texas',
 (48, 253): u'Jones County, Texas',
 (48, 255): u'Karnes County, Texas',
 (48, 257): u'Kaufman County, Texas',
 (48, 259): u'Kendall County, Texas',
 (48, 261): u'Kenedy County, Texas',
 (48, 263): u'Kent County, Texas',
 (48, 265): u'Kerr County, Texas',
 (48, 267): u'Kimble County, Texas',
 (48, 269): u'King County, Texas',
 (48, 271): u'Kinney County, Texas',
 (48, 273): u'Kleberg County, Texas',
 (48, 275): u'Knox County, Texas',
 (48, 277): u'Lamar County, Texas',
 (48, 279): u'Lamb County, Texas',
 (48, 281): u'Lampasas County, Texas',
 (48, 283): u'La Salle County, Texas',
 (48, 285): u'Lavaca County, Texas',
 (48, 287): u'Lee County, Texas',
 (48, 289): u'Leon County, Texas',
 (48, 291): u'Liberty County, Texas',
 (48, 293): u'Limestone County, Texas',
 (48, 295): u'Lipscomb County, Texas',
 (48, 297): u'Live Oak County, Texas',
 (48, 299): u'Llano County, Texas',
 (48, 301): u'Loving County, Texas',
 (48, 303): u'Lubbock County, Texas',
 (48, 305): u'Lynn County, Texas',
 (48, 307): u'McCulloch County, Texas',
 (48, 309): u'McLennan County, Texas',
 (48, 311): u'McMullen County, Texas',
 (48, 313): u'Madison County, Texas',
 (48, 315): u'Marion County, Texas',
 (48, 317): u'Martin County, Texas',
 (48, 319): u'Mason County, Texas',
 (48, 321): u'Matagorda County, Texas',
 (48, 323): u'Maverick County, Texas',
 (48, 325): u'Medina County, Texas',
 (48, 327): u'Menard County, Texas',
 (48, 329): u'Midland County, Texas',
 (48, 331): u'Milam County, Texas',
 (48, 333): u'Mills County, Texas',
 (48, 335): u'Mitchell County, Texas',
 (48, 337): u'Montague County, Texas',
 (48, 339): u'Montgomery County, Texas',
 (48, 341): u'Moore County, Texas',
 (48, 343): u'Morris County, Texas',
 (48, 345): u'Motley County, Texas',
 (48, 347): u'Nacogdoches County, Texas',
 (48, 349): u'Navarro County, Texas',
 (48, 351): u'Newton County, Texas',
 (48, 353): u'Nolan County, Texas',
 (48, 355): u'Nueces County, Texas',
 (48, 357): u'Ochiltree County, Texas',
 (48, 359): u'Oldham County, Texas',
 (48, 361): u'Orange County, Texas',
 (48, 363): u'Palo Pinto County, Texas',
 (48, 365): u'Panola County, Texas',
 (48, 367): u'Parker County, Texas',
 (48, 369): u'Parmer County, Texas',
 (48, 371): u'Pecos County, Texas',
 (48, 373): u'Polk County, Texas',
 (48, 375): u'Potter County, Texas',
 (48, 377): u'Presidio County, Texas',
 (48, 379): u'Rains County, Texas',
 (48, 381): u'Randall County, Texas',
 (48, 383): u'Reagan County, Texas',
 (48, 385): u'Real County, Texas',
 (48, 387): u'Red River County, Texas',
 (48, 389): u'Reeves County, Texas',
 (48, 391): u'Refugio County, Texas',
 (48, 393): u'Roberts County, Texas',
 (48, 395): u'Robertson County, Texas',
 (48, 397): u'Rockwall County, Texas',
 (48, 399): u'Runnels County, Texas',
 (48, 401): u'Rusk County, Texas',
 (48, 403): u'Sabine County, Texas',
 (48, 405): u'San Augustine County, Texas',
 (48, 407): u'San Jacinto County, Texas',
 (48, 409): u'San Patricio County, Texas',
 (48, 411): u'San Saba County, Texas',
 (48, 413): u'Schleicher County, Texas',
 (48, 415): u'Scurry County, Texas',
 (48, 417): u'Shackelford County, Texas',
 (48, 419): u'Shelby County, Texas',
 (48, 421): u'Sherman County, Texas',
 (48, 423): u'Smith County, Texas',
 (48, 425): u'Somervell County, Texas',
 (48, 427): u'Starr County, Texas',
 (48, 429): u'Stephens County, Texas',
 (48, 431): u'Sterling County, Texas',
 (48, 433): u'Stonewall County, Texas',
 (48, 435): u'Sutton County, Texas',
 (48, 437): u'Swisher County, Texas',
 (48, 439): u'Tarrant County, Texas',
 (48, 441): u'Taylor County, Texas',
 (48, 443): u'Terrell County, Texas',
 (48, 445): u'Terry County, Texas',
 (48, 447): u'Throckmorton County, Texas',
 (48, 449): u'Titus County, Texas',
 (48, 451): u'Tom Green County, Texas',
 (48, 453): u'Travis County, Texas',
 (48, 455): u'Trinity County, Texas',
 (48, 457): u'Tyler County, Texas',
 (48, 459): u'Upshur County, Texas',
 (48, 461): u'Upton County, Texas',
 (48, 463): u'Uvalde County, Texas',
 (48, 465): u'Val Verde County, Texas',
 (48, 467): u'Van Zandt County, Texas',
 (48, 469): u'Victoria County, Texas',
 (48, 471): u'Walker County, Texas',
 (48, 473): u'Waller County, Texas',
 (48, 475): u'Ward County, Texas',
 (48, 477): u'Washington County, Texas',
 (48, 479): u'Webb County, Texas',
 (48, 481): u'Wharton County, Texas',
 (48, 483): u'Wheeler County, Texas',
 (48, 485): u'Wichita County, Texas',
 (48, 487): u'Wilbarger County, Texas',
 (48, 489): u'Willacy County, Texas',
 (48, 491): u'Williamson County, Texas',
 (48, 493): u'Wilson County, Texas',
 (48, 495): u'Winkler County, Texas',
 (48, 497): u'Wise County, Texas',
 (48, 499): u'Wood County, Texas',
 (48, 501): u'Yoakum County, Texas',
 (48, 503): u'Young County, Texas',
 (48, 505): u'Zapata County, Texas',
 (48, 507): u'Zavala County, Texas',
 (49, 0): u'Utah',
 (49, 1): u'Beaver County, Utah',
 (49, 3): u'Box Elder County, Utah',
 (49, 5): u'Cache County, Utah',
 (49, 7): u'Carbon County, Utah',
 (49, 9): u'Daggett County, Utah',
 (49, 11): u'Davis County, Utah',
 (49, 13): u'Duchesne County, Utah',
 (49, 15): u'Emery County, Utah',
 (49, 17): u'Garfield County, Utah',
 (49, 19): u'Grand County, Utah',
 (49, 21): u'Iron County, Utah',
 (49, 23): u'Juab County, Utah',
 (49, 25): u'Kane County, Utah',
 (49, 27): u'Millard County, Utah',
 (49, 29): u'Morgan County, Utah',
 (49, 31): u'Piute County, Utah',
 (49, 33): u'Rich County, Utah',
 (49, 35): u'Salt Lake County, Utah',
 (49, 37): u'San Juan County, Utah',
 (49, 39): u'Sanpete County, Utah',
 (49, 41): u'Sevier County, Utah',
 (49, 43): u'Summit County, Utah',
 (49, 45): u'Tooele County, Utah',
 (49, 47): u'Uintah County, Utah',
 (49, 49): u'Utah County, Utah',
 (49, 51): u'Wasatch County, Utah',
 (49, 53): u'Washington County, Utah',
 (49, 55): u'Wayne County, Utah',
 (49, 57): u'Weber County, Utah',
 (50, 0): u'Vermont',
 (50, 1): u'Addison County, Vermont',
 (50, 3): u'Bennington County, Vermont',
 (50, 5): u'Caledonia County, Vermont',
 (50, 7): u'Chittenden County, Vermont',
 (50, 9): u'Essex County, Vermont',
 (50, 11): u'Franklin County, Vermont',
 (50, 13): u'Grand Isle County, Vermont',
 (50, 15): u'Lamoille County, Vermont',
 (50, 17): u'Orange County, Vermont',
 (50, 19): u'Orleans County, Vermont',
 (50, 21): u'Rutland County, Vermont',
 (50, 23): u'Washington County, Vermont',
 (50, 25): u'Windham County, Vermont',
 (50, 27): u'Windsor County, Vermont',
 (51, 0): u'Virginia',
 (51, 1): u'Accomack County, Virginia',
 (51, 3): u'Albemarle County, Virginia',
 (51, 5): u'Alleghany County, Virginia',
 (51, 7): u'Amelia County, Virginia',
 (51, 9): u'Amherst County, Virginia',
 (51, 11): u'Appomattox County, Virginia',
 (51, 13): u'Arlington County, Virginia',
 (51, 15): u'Augusta County, Virginia',
 (51, 17): u'Bath County, Virginia',
 (51, 19): u'Bedford County, Virginia',
 (51, 21): u'Bland County, Virginia',
 (51, 23): u'Botetourt County, Virginia',
 (51, 25): u'Brunswick County, Virginia',
 (51, 27): u'Buchanan County, Virginia',
 (51, 29): u'Buckingham County, Virginia',
 (51, 31): u'Campbell County, Virginia',
 (51, 33): u'Caroline County, Virginia',
 (51, 35): u'Carroll County, Virginia',
 (51, 36): u'Charles City County, Virginia',
 (51, 37): u'Charlotte County, Virginia',
 (51, 41): u'Chesterfield County, Virginia',
 (51, 43): u'Clarke County, Virginia',
 (51, 45): u'Craig County, Virginia',
 (51, 47): u'Culpeper County, Virginia',
 (51, 49): u'Cumberland County, Virginia',
 (51, 51): u'Dickenson County, Virginia',
 (51, 53): u'Dinwiddie County, Virginia',
 (51, 57): u'Essex County, Virginia',
 (51, 59): u'Fairfax County, Virginia',
 (51, 61): u'Fauquier County, Virginia',
 (51, 63): u'Floyd County, Virginia',
 (51, 65): u'Fluvanna County, Virginia',
 (51, 67): u'Franklin County, Virginia',
 (51, 69): u'Frederick County, Virginia',
 (51, 71): u'Giles County, Virginia',
 (51, 73): u'Gloucester County, Virginia',
 (51, 75): u'Goochland County, Virginia',
 (51, 77): u'Grayson County, Virginia',
 (51, 79): u'Greene County, Virginia',
 (51, 81): u'Greensville County, Virginia',
 (51, 83): u'Halifax County, Virginia',
 (51, 85): u'Hanover County, Virginia',
 (51, 87): u'Henrico County, Virginia',
 (51, 89): u'Henry County, Virginia',
 (51, 91): u'Highland County, Virginia',
 (51, 93): u'Isle of Wight County, Virginia',
 (51, 95): u'James City County, Virginia',
 (51, 97): u'King and Queen County, Virginia',
 (51, 99): u'King George County, Virginia',
 (51, 101): u'King William County, Virginia',
 (51, 103): u'Lancaster County, Virginia',
 (51, 105): u'Lee County, Virginia',
 (51, 107): u'Loudoun County, Virginia',
 (51, 109): u'Louisa County, Virginia',
 (51, 111): u'Lunenburg County, Virginia',
 (51, 113): u'Madison County, Virginia',
 (51, 115): u'Mathews County, Virginia',
 (51, 117): u'Mecklenburg County, Virginia',
 (51, 119): u'Middlesex County, Virginia',
 (51, 121): u'Montgomery County, Virginia',
 (51, 125): u'Nelson County, Virginia',
 (51, 127): u'New Kent County, Virginia',
 (51, 131): u'Northampton County, Virginia',
 (51, 133): u'Northumberland County, Virginia',
 (51, 135): u'Nottoway County, Virginia',
 (51, 137): u'Orange County, Virginia',
 (51, 139): u'Page County, Virginia',
 (51, 141): u'Patrick County, Virginia',
 (51, 143): u'Pittsylvania County, Virginia',
 (51, 145): u'Powhatan County, Virginia',
 (51, 147): u'Prince Edward County, Virginia',
 (51, 149): u'Prince George County, Virginia',
 (51, 153): u'Prince William County, Virginia',
 (51, 155): u'Pulaski County, Virginia',
 (51, 157): u'Rappahannock County, Virginia',
 (51, 159): u'Richmond County, Virginia',
 (51, 161): u'Roanoke County, Virginia',
 (51, 163): u'Rockbridge County, Virginia',
 (51, 165): u'Rockingham County, Virginia',
 (51, 167): u'Russell County, Virginia',
 (51, 169): u'Scott County, Virginia',
 (51, 171): u'Shenandoah County, Virginia',
 (51, 173): u'Smyth County, Virginia',
 (51, 175): u'Southampton County, Virginia',
 (51, 177): u'Spotsylvania County, Virginia',
 (51, 179): u'Stafford County, Virginia',
 (51, 181): u'Surry County, Virginia',
 (51, 183): u'Sussex County, Virginia',
 (51, 185): u'Tazewell County, Virginia',
 (51, 187): u'Warren County, Virginia',
 (51, 191): u'Washington County, Virginia',
 (51, 193): u'Westmoreland County, Virginia',
 (51, 195): u'Wise County, Virginia',
 (51, 197): u'Wythe County, Virginia',
 (51, 199): u'York County, Virginia',
 (51, 510): u'Alexandria city, Virginia',
 (51, 515): u'Bedford city, Virginia',
 (51, 520): u'Bristol city, Virginia',
 (51, 530): u'Buena Vista city, Virginia',
 (51, 540): u'Charlottesville city, Virginia',
 (51, 550): u'Chesapeake city, Virginia',
 (51, 570): u'Colonial Heights city, Virginia',
 (51, 580): u'Covington city, Virginia',
 (51, 590): u'Danville city, Virginia',
 (51, 595): u'Emporia city, Virginia',
 (51, 600): u'Fairfax city, Virginia',
 (51, 610): u'Falls Church city, Virginia',
 (51, 620): u'Franklin city, Virginia',
 (51, 630): u'Fredericksburg city, Virginia',
 (51, 640): u'Galax city, Virginia',
 (51, 650): u'Hampton city, Virginia',
 (51, 660): u'Harrisonburg city, Virginia',
 (51, 670): u'Hopewell city, Virginia',
 (51, 678): u'Lexington city, Virginia',
 (51, 680): u'Lynchburg city, Virginia',
 (51, 683): u'Manassas city, Virginia',
 (51, 685): u'Manassas Park city, Virginia',
 (51, 690): u'Martinsville city, Virginia',
 (51, 700): u'Newport News city, Virginia',
 (51, 710): u'Norfolk city, Virginia',
 (51, 720): u'Norton city, Virginia',
 (51, 730): u'Petersburg city, Virginia',
 (51, 735): u'Poquoson city, Virginia',
 (51, 740): u'Portsmouth city, Virginia',
 (51, 750): u'Radford city, Virginia',
 (51, 760): u'Richmond city, Virginia',
 (51, 770): u'Roanoke city, Virginia',
 (51, 775): u'Salem city, Virginia',
 (51, 790): u'Staunton city, Virginia',
 (51, 800): u'Suffolk city, Virginia',
 (51, 810): u'Virginia Beach city, Virginia',
 (51, 820): u'Waynesboro city, Virginia',
 (51, 830): u'Williamsburg city, Virginia',
 (51, 840): u'Winchester city, Virginia',
 (53, 0): u'Washington',
 (53, 1): u'Adams County, Washington',
 (53, 3): u'Asotin County, Washington',
 (53, 5): u'Benton County, Washington',
 (53, 7): u'Chelan County, Washington',
 (53, 9): u'Clallam County, Washington',
 (53, 11): u'Clark County, Washington',
 (53, 13): u'Columbia County, Washington',
 (53, 15): u'Cowlitz County, Washington',
 (53, 17): u'Douglas County, Washington',
 (53, 19): u'Ferry County, Washington',
 (53, 21): u'Franklin County, Washington',
 (53, 23): u'Garfield County, Washington',
 (53, 25): u'Grant County, Washington',
 (53, 27): u'Grays Harbor County, Washington',
 (53, 29): u'Island County, Washington',
 (53, 31): u'Jefferson County, Washington',
 (53, 33): u'King County, Washington',
 (53, 35): u'Kitsap County, Washington',
 (53, 37): u'Kittitas County, Washington',
 (53, 39): u'Klickitat County, Washington',
 (53, 41): u'Lewis County, Washington',
 (53, 43): u'Lincoln County, Washington',
 (53, 45): u'Mason County, Washington',
 (53, 47): u'Okanogan County, Washington',
 (53, 49): u'Pacific County, Washington',
 (53, 51): u'Pend Oreille County, Washington',
 (53, 53): u'Pierce County, Washington',
 (53, 55): u'San Juan County, Washington',
 (53, 57): u'Skagit County, Washington',
 (53, 59): u'Skamania County, Washington',
 (53, 61): u'Snohomish County, Washington',
 (53, 63): u'Spokane County, Washington',
 (53, 65): u'Stevens County, Washington',
 (53, 67): u'Thurston County, Washington',
 (53, 69): u'Wahkiakum County, Washington',
 (53, 71): u'Walla Walla County, Washington',
 (53, 73): u'Whatcom County, Washington',
 (53, 75): u'Whitman County, Washington',
 (53, 77): u'Yakima County, Washington',
 (54, 0): u'West Virginia',
 (54, 1): u'Barbour County, West Virginia',
 (54, 3): u'Berkeley County, West Virginia',
 (54, 5): u'Boone County, West Virginia',
 (54, 7): u'Braxton County, West Virginia',
 (54, 9): u'Brooke County, West Virginia',
 (54, 11): u'Cabell County, West Virginia',
 (54, 13): u'Calhoun County, West Virginia',
 (54, 15): u'Clay County, West Virginia',
 (54, 17): u'Doddridge County, West Virginia',
 (54, 19): u'Fayette County, West Virginia',
 (54, 21): u'Gilmer County, West Virginia',
 (54, 23): u'Grant County, West Virginia',
 (54, 25): u'Greenbrier County, West Virginia',
 (54, 27): u'Hampshire County, West Virginia',
 (54, 29): u'Hancock County, West Virginia',
 (54, 31): u'Hardy County, West Virginia',
 (54, 33): u'Harrison County, West Virginia',
 (54, 35): u'Jackson County, West Virginia',
 (54, 37): u'Jefferson County, West Virginia',
 (54, 39): u'Kanawha County, West Virginia',
 (54, 41): u'Lewis County, West Virginia',
 (54, 43): u'Lincoln County, West Virginia',
 (54, 45): u'Logan County, West Virginia',
 (54, 47): u'McDowell County, West Virginia',
 (54, 49): u'Marion County, West Virginia',
 (54, 51): u'Marshall County, West Virginia',
 (54, 53): u'Mason County, West Virginia',
 (54, 55): u'Mercer County, West Virginia',
 (54, 57): u'Mineral County, West Virginia',
 (54, 59): u'Mingo County, West Virginia',
 (54, 61): u'Monongalia County, West Virginia',
 (54, 63): u'Monroe County, West Virginia',
 (54, 65): u'Morgan County, West Virginia',
 (54, 67): u'Nicholas County, West Virginia',
 (54, 69): u'Ohio County, West Virginia',
 (54, 71): u'Pendleton County, West Virginia',
 (54, 73): u'Pleasants County, West Virginia',
 (54, 75): u'Pocahontas County, West Virginia',
 (54, 77): u'Preston County, West Virginia',
 (54, 79): u'Putnam County, West Virginia',
 (54, 81): u'Raleigh County, West Virginia',
 (54, 83): u'Randolph County, West Virginia',
 (54, 85): u'Ritchie County, West Virginia',
 (54, 87): u'Roane County, West Virginia',
 (54, 89): u'Summers County, West Virginia',
 (54, 91): u'Taylor County, West Virginia',
 (54, 93): u'Tucker County, West Virginia',
 (54, 95): u'Tyler County, West Virginia',
 (54, 97): u'Upshur County, West Virginia',
 (54, 99): u'Wayne County, West Virginia',
 (54, 101): u'Webster County, West Virginia',
 (54, 103): u'Wetzel County, West Virginia',
 (54, 105): u'Wirt County, West Virginia',
 (54, 107): u'Wood County, West Virginia',
 (54, 109): u'Wyoming County, West Virginia',
 (55, 0): u'Wisconsin',
 (55, 1): u'Adams County, Wisconsin',
 (55, 3): u'Ashland County, Wisconsin',
 (55, 5): u'Barron County, Wisconsin',
 (55, 7): u'Bayfield County, Wisconsin',
 (55, 9): u'Brown County, Wisconsin',
 (55, 11): u'Buffalo County, Wisconsin',
 (55, 13): u'Burnett County, Wisconsin',
 (55, 15): u'Calumet County, Wisconsin',
 (55, 17): u'Chippewa County, Wisconsin',
 (55, 19): u'Clark County, Wisconsin',
 (55, 21): u'Columbia County, Wisconsin',
 (55, 23): u'Crawford County, Wisconsin',
 (55, 25): u'Dane County, Wisconsin',
 (55, 27): u'Dodge County, Wisconsin',
 (55, 29): u'Door County, Wisconsin',
 (55, 31): u'Douglas County, Wisconsin',
 (55, 33): u'Dunn County, Wisconsin',
 (55, 35): u'Eau Claire County, Wisconsin',
 (55, 37): u'Florence County, Wisconsin',
 (55, 39): u'Fond du Lac County, Wisconsin',
 (55, 41): u'Forest County, Wisconsin',
 (55, 43): u'Grant County, Wisconsin',
 (55, 45): u'Green County, Wisconsin',
 (55, 47): u'Green Lake County, Wisconsin',
 (55, 49): u'Iowa County, Wisconsin',
 (55, 51): u'Iron County, Wisconsin',
 (55, 53): u'Jackson County, Wisconsin',
 (55, 55): u'Jefferson County, Wisconsin',
 (55, 57): u'Juneau County, Wisconsin',
 (55, 59): u'Kenosha County, Wisconsin',
 (55, 61): u'Kewaunee County, Wisconsin',
 (55, 63): u'La Crosse County, Wisconsin',
 (55, 65): u'Lafayette County, Wisconsin',
 (55, 67): u'Langlade County, Wisconsin',
 (55, 69): u'Lincoln County, Wisconsin',
 (55, 71): u'Manitowoc County, Wisconsin',
 (55, 73): u'Marathon County, Wisconsin',
 (55, 75): u'Marinette County, Wisconsin',
 (55, 77): u'Marquette County, Wisconsin',
 (55, 78): u'Menominee County, Wisconsin',
 (55, 79): u'Milwaukee County, Wisconsin',
 (55, 81): u'Monroe County, Wisconsin',
 (55, 83): u'Oconto County, Wisconsin',
 (55, 85): u'Oneida County, Wisconsin',
 (55, 87): u'Outagamie County, Wisconsin',
 (55, 89): u'Ozaukee County, Wisconsin',
 (55, 91): u'Pepin County, Wisconsin',
 (55, 93): u'Pierce County, Wisconsin',
 (55, 95): u'Polk County, Wisconsin',
 (55, 97): u'Portage County, Wisconsin',
 (55, 99): u'Price County, Wisconsin',
 (55, 101): u'Racine County, Wisconsin',
 (55, 103): u'Richland County, Wisconsin',
 (55, 105): u'Rock County, Wisconsin',
 (55, 107): u'Rusk County, Wisconsin',
 (55, 109): u'St. Croix County, Wisconsin',
 (55, 111): u'Sauk County, Wisconsin',
 (55, 113): u'Sawyer County, Wisconsin',
 (55, 115): u'Shawano County, Wisconsin',
 (55, 117): u'Sheboygan County, Wisconsin',
 (55, 119): u'Taylor County, Wisconsin',
 (55, 121): u'Trempealeau County, Wisconsin',
 (55, 123): u'Vernon County, Wisconsin',
 (55, 125): u'Vilas County, Wisconsin',
 (55, 127): u'Walworth County, Wisconsin',
 (55, 129): u'Washburn County, Wisconsin',
 (55, 131): u'Washington County, Wisconsin',
 (55, 133): u'Waukesha County, Wisconsin',
 (55, 135): u'Waupaca County, Wisconsin',
 (55, 137): u'Waushara County, Wisconsin',
 (55, 139): u'Winnebago County, Wisconsin',
 (55, 141): u'Wood County, Wisconsin',
 (56, 0): u'Wyoming',
 (56, 1): u'Albany County, Wyoming',
 (56, 3): u'Big Horn County, Wyoming',
 (56, 5): u'Campbell County, Wyoming',
 (56, 7): u'Carbon County, Wyoming',
 (56, 9): u'Converse County, Wyoming',
 (56, 11): u'Crook County, Wyoming',
 (56, 13): u'Fremont County, Wyoming',
 (56, 15): u'Goshen County, Wyoming',
 (56, 17): u'Hot Springs County, Wyoming',
 (56, 19): u'Johnson County, Wyoming',
 (56, 21): u'Laramie County, Wyoming',
 (56, 23): u'Lincoln County, Wyoming',
 (56, 25): u'Natrona County, Wyoming',
 (56, 27): u'Niobrara County, Wyoming',
 (56, 29): u'Park County, Wyoming',
 (56, 31): u'Platte County, Wyoming',
 (56, 33): u'Sheridan County, Wyoming',
 (56, 35): u'Sublette County, Wyoming',
 (56, 37): u'Sweetwater County, Wyoming',
 (56, 39): u'Teton County, Wyoming',
 (56, 41): u'Uinta County, Wyoming',
 (56, 43): u'Washakie County, Wyoming',
 (56, 45): u'Weston County, Wyoming',
 (72, 0): u'Puerto Rico',
 (72, 1): u'Adjuntas Municipio, Puerto Rico',
 (72, 3): u'Aguada Municipio, Puerto Rico',
 (72, 5): u'Aguadilla Municipio, Puerto Rico',
 (72, 7): u'Aguas Buenas Municipio, Puerto Rico',
 (72, 9): u'Aibonito Municipio, Puerto Rico',
 (72, 11): u'A\xf1asco Municipio, Puerto Rico',
 (72, 13): u'Arecibo Municipio, Puerto Rico',
 (72, 15): u'Arroyo Municipio, Puerto Rico',
 (72, 17): u'Barceloneta Municipio, Puerto Rico',
 (72, 19): u'Barranquitas Municipio, Puerto Rico',
 (72, 21): u'Bayam\xf3n Municipio, Puerto Rico',
 (72, 23): u'Cabo Rojo Municipio, Puerto Rico',
 (72, 25): u'Caguas Municipio, Puerto Rico',
 (72, 27): u'Camuy Municipio, Puerto Rico',
 (72, 29): u'Can\xf3vanas Municipio, Puerto Rico',
 (72, 31): u'Carolina Municipio, Puerto Rico',
 (72, 33): u'Cata\xf1o Municipio, Puerto Rico',
 (72, 35): u'Cayey Municipio, Puerto Rico',
 (72, 37): u'Ceiba Municipio, Puerto Rico',
 (72, 39): u'Ciales Municipio, Puerto Rico',
 (72, 41): u'Cidra Municipio, Puerto Rico',
 (72, 43): u'Coamo Municipio, Puerto Rico',
 (72, 45): u'Comer\xedo Municipio, Puerto Rico',
 (72, 47): u'Corozal Municipio, Puerto Rico',
 (72, 49): u'Culebra Municipio, Puerto Rico',
 (72, 51): u'Dorado Municipio, Puerto Rico',
 (72, 53): u'Fajardo Municipio, Puerto Rico',
 (72, 54): u'Florida Municipio, Puerto Rico',
 (72, 55): u'Gu\xe1nica Municipio, Puerto Rico',
 (72, 57): u'Guayama Municipio, Puerto Rico',
 (72, 59): u'Guayanilla Municipio, Puerto Rico',
 (72, 61): u'Guaynabo Municipio, Puerto Rico',
 (72, 63): u'Gurabo Municipio, Puerto Rico',
 (72, 65): u'Hatillo Municipio, Puerto Rico',
 (72, 67): u'Hormigueros Municipio, Puerto Rico',
 (72, 69): u'Humacao Municipio, Puerto Rico',
 (72, 71): u'Isabela Municipio, Puerto Rico',
 (72, 73): u'Jayuya Municipio, Puerto Rico',
 (72, 75): u'Juana D\xedaz Municipio, Puerto Rico',
 (72, 77): u'Juncos Municipio, Puerto Rico',
 (72, 79): u'Lajas Municipio, Puerto Rico',
 (72, 81): u'Lares Municipio, Puerto Rico',
 (72, 83): u'Las Mar\xedas Municipio, Puerto Rico',
 (72, 85): u'Las Piedras Municipio, Puerto Rico',
 (72, 87): u'Lo\xedza Municipio, Puerto Rico',
 (72, 89): u'Luquillo Municipio, Puerto Rico',
 (72, 91): u'Manat\xed Municipio, Puerto Rico',
 (72, 93): u'Maricao Municipio, Puerto Rico',
 (72, 95): u'Maunabo Municipio, Puerto Rico',
 (72, 97): u'Mayag\xfcez Municipio, Puerto Rico',
 (72, 99): u'Moca Municipio, Puerto Rico',
 (72, 101): u'Morovis Municipio, Puerto Rico',
 (72, 103): u'Naguabo Municipio, Puerto Rico',
 (72, 105): u'Naranjito Municipio, Puerto Rico',
 (72, 107): u'Orocovis Municipio, Puerto Rico',
 (72, 109): u'Patillas Municipio, Puerto Rico',
 (72, 111): u'Pe\xf1uelas Municipio, Puerto Rico',
 (72, 113): u'Ponce Municipio, Puerto Rico',
 (72, 115): u'Quebradillas Municipio, Puerto Rico',
 (72, 117): u'Rinc\xf3n Municipio, Puerto Rico',
 (72, 119): u'R\xedo Grande Municipio, Puerto Rico',
 (72, 121): u'Sabana Grande Municipio, Puerto Rico',
 (72, 123): u'Salinas Municipio, Puerto Rico',
 (72, 125): u'San Germ\xe1n Municipio, Puerto Rico',
 (72, 127): u'San Juan Municipio, Puerto Rico',
 (72, 129): u'San Lorenzo Municipio, Puerto Rico',
 (72, 131): u'San Sebasti\xe1n Municipio, Puerto Rico',
 (72, 133): u'Santa Isabel Municipio, Puerto Rico',
 (72, 135): u'Toa Alta Municipio, Puerto Rico',
 (72, 137): u'Toa Baja Municipio, Puerto Rico',
 (72, 139): u'Trujillo Alto Municipio, Puerto Rico',
 (72, 141): u'Utuado Municipio, Puerto Rico',
 (72, 143): u'Vega Alta Municipio, Puerto Rico',
 (72, 145): u'Vega Baja Municipio, Puerto Rico',
 (72, 147): u'Vieques Municipio, Puerto Rico',
 (72, 149): u'Villalba Municipio, Puerto Rico',
 (72, 151): u'Yabucoa Municipio, Puerto Rico',
 (72, 153): u'Yauco Municipio, Puerto Rico'}

stusab = {
 1: 'AL',
 2: 'AK',
 4: 'AZ',
 5: 'AR',
 6: 'CA',
 8: 'CO',
 9: 'CT',
 10: 'DE',
 11: 'DC',
 12: 'FL',
 13: 'GA',
 15: 'HI',
 16: 'ID',
 17: 'IL',
 18: 'IN',
 19: 'IA',
 20: 'KS',
 21: 'KY',
 22: 'LA',
 23: 'ME',
 24: 'MD',
 25: 'MA',
 26: 'MI',
 27: 'MN',
 28: 'MS',
 29: 'MO',
 30: 'MT',
 31: 'NE',
 32: 'NV',
 33: 'NH',
 34: 'NJ',
 35: 'NM',
 36: 'NY',
 37: 'NC',
 38: 'ND',
 39: 'OH',
 40: 'OK',
 41: 'OR',
 42: 'PA',
 44: 'RI',
 45: 'SC',
 46: 'SD',
 47: 'TN',
 48: 'TX',
 49: 'UT',
 50: 'VT',
 51: 'VA',
 53: 'WA',
 54: 'WV',
 55: 'WI',
 56: 'WY',
 72: 'PR'
}